@@ -330,8 +330,13 @@ public:
 	{}
 
 
+	/// Get smoothed value
 	float value() const { return mValue; }
 
+	/// Get target value
+	float target() const { return mTarget; }
+
+	/// Set target value
 	Param& operator= (float target){
 		mTarget = target;
 		return *this;
@@ -342,6 +347,7 @@ public:
 		return *this;
 	}
 
+	/// Set smoothing coefficient
 	Param& smooth(float v){
 		mSmooth = v;
 		return *this;
@@ -454,9 +460,11 @@ public:
 
 
 	/// Get an array of the voices
+	const VoiceGen * voices() const { return mVoiceGens; }
 	VoiceGen * voices(){ return mVoiceGens; }
 
 	/// Get a reference to the voice at the specified index
+	const VoiceGen& voice(unsigned i) const { return mVoiceGens[i]; }
 	VoiceGen& voice(unsigned i){ return mVoiceGens[i]; }
 
 	VoiceGen * begin(){ return mVoiceGens; }
@@ -516,11 +524,10 @@ public:
 	/// @param[in] f	Called with newly obtained voice, just before playing it
 	///
 	Voices& attackWithID(unsigned ID, const std::function<void(VoiceGen&)>& f){
-		auto& v = obtain();
-		f(v);
-		mIndexPool.idToIndex()[ID] = v.mIndex;
-		play(v);
-		return *this;
+		return attack([&](auto& v){
+			mIndexPool.idToIndex()[ID] = v.mIndex;
+			f(v);
+		});
 	}
 
 	/// Start new voice
