@@ -120,7 +120,7 @@ struct soundfile_storage : soundfile_input_storage<T>
         buf[i] = g->data[i].data();
 
       // Update the port
-      for(auto& state : t.full_state())
+      for(auto state : t.full_state())
       {
         auto& port = avnd::pfr::get<NField>(state.inputs);
         port.soundfile.data = buf.data();
@@ -149,7 +149,7 @@ struct soundfile_storage : soundfile_input_storage<T>
       }
 
       // Update the port
-      for(auto& state : t.full_state())
+      for(auto state : t.full_state())
       {
         auto& port = avnd::pfr::get<NField>(state.inputs);
         port.soundfile.data = buf.data();
@@ -216,7 +216,7 @@ struct midifile_storage : midifile_input_storage<T>
     // Store the handle to keep the memory from being freed
     std::exchange(g, hdl);
 
-    for(auto& state : t.full_state())
+    for(auto state : t.full_state())
     {
       avnd::midifile_port auto& port = avnd::pfr::get<NField>(state.inputs);
 
@@ -231,7 +231,7 @@ struct midifile_storage : midifile_input_storage<T>
         auto& out = port.midifile.tracks[i];
         using message_type = std::decay_t<decltype(out[0])>;
         using bytes_type = std::remove_reference_t<decltype(message_type::bytes)>;
-        constexpr bool is_c_array = std::is_bounded_array_v<bytes_type>;
+        static constexpr bool is_c_array = std::is_bounded_array_v<bytes_type>;
 
         if constexpr(is_c_array)
           out.reserve(in.size());
@@ -343,15 +343,41 @@ struct raw_file_storage : raw_file_input_storage<T>
     // Store the handle to keep the memory from being freed
     std::exchange(g, hdl);
 
-    for(auto& state : t.full_state())
+    for(auto state : t.full_state())
     {
       avnd::raw_file_port auto& port = avnd::pfr::get<NField>(state.inputs);
 
+      if(port.file.filename != hdl->filename)
+      {
+        port.file.bytes
+            = decltype(port.file.bytes)(hdl->data.constData(), hdl->file.size());
+        port.file.filename = hdl->filename;
+
+        if_possible(port.update(state.effect));
+      }
+    }
+  }
+
+  template <std::size_t N, std::size_t NField>
+  void load(
+      T& state, const std::shared_ptr<raw_file_data>& hdl, avnd::predicate_index<N>,
+      avnd::field_index<NField>)
+  {
+    std::shared_ptr<raw_file_data>& g = get<N>(this->handles);
+
+    // Store the handle to keep the memory from being freed
+    std::exchange(g, hdl);
+
+    // FIXME not generic enough.. GPU should also use effect_container
+    avnd::raw_file_port auto& port = avnd::pfr::get<NField>(state.inputs);
+
+    if(port.file.filename != hdl->filename)
+    {
       port.file.bytes
           = decltype(port.file.bytes)(hdl->data.constData(), hdl->file.size());
       port.file.filename = hdl->filename;
 
-      if_possible(port.update(state.effect));
+      if_possible(port.update(state));
     }
   }
 };
