@@ -36,7 +36,7 @@ struct event_bus_info
       info.mediaType = MediaTypes::kEvent;
       info.direction = BusDirections::kInput;
       info.channelCount = 1;
-      setStr(info.name, u16 "Event in");
+      setStr(info.name, u16_str "Event in");
       info.busType = BusTypes::kMain;
       info.flags = BusInfo::kDefaultActive;
 
@@ -60,7 +60,7 @@ struct event_bus_info
       info.mediaType = MediaTypes::kEvent;
       info.direction = BusDirections::kOutput;
       info.channelCount = 1;
-      setStr(info.name, u16 "Event Out");
+      setStr(info.name, u16_str "Event Out");
       info.busType = BusTypes::kMain;
       info.flags = BusInfo::kDefaultActive;
 
@@ -235,7 +235,7 @@ struct audio_bus_info<T>
     if(index == 0)
     {
       info.channelCount = avnd::input_channels<T>(2);
-      setStr(info.name, u16 "Stereo In");
+      setStr(info.name, u16_str "Stereo In");
       info.busType = Steinberg::Vst::BusTypes::kMain;
 
       return Steinberg::kResultTrue;
@@ -250,7 +250,7 @@ struct audio_bus_info<T>
     if(index == 0)
     {
       info.channelCount = avnd::output_channels<T>(2);
-      setStr(info.name, u16 "Stereo Out");
+      setStr(info.name, u16_str "Stereo Out");
       info.busType = Steinberg::Vst::BusTypes::kMain;
 
       return Steinberg::kResultTrue;
@@ -339,7 +339,7 @@ struct audio_bus_info<T>
     if(index == 0)
     {
       info.channelCount = avnd::input_channels<T>(2);
-      setStr(info.name, u16 "Mono In");
+      setStr(info.name, u16_str "Mono In");
       info.busType = Steinberg::Vst::BusTypes::kMain;
 
       return Steinberg::kResultTrue;
@@ -354,7 +354,7 @@ struct audio_bus_info<T>
     if(index == 0)
     {
       info.channelCount = avnd::output_channels<T>(2);
-      setStr(info.name, u16 "Mono Out");
+      setStr(info.name, u16_str "Mono Out");
       info.busType = Steinberg::Vst::BusTypes::kMain;
 
       return Steinberg::kResultTrue;
@@ -443,7 +443,7 @@ struct audio_bus_info<T>
     if(index == 0)
     {
       info.channelCount = avnd::input_channels<T>(2);
-      setStr(info.name, u16 "Mono In");
+      setStr(info.name, u16_str "Mono In");
       info.busType = Steinberg::Vst::BusTypes::kMain;
 
       return Steinberg::kResultTrue;
@@ -458,7 +458,7 @@ struct audio_bus_info<T>
     if(index == 0)
     {
       info.channelCount = avnd::output_channels<T>(2);
-      setStr(info.name, u16 "Mono Out");
+      setStr(info.name, u16_str "Mono Out");
       info.busType = Steinberg::Vst::BusTypes::kMain;
 
       return Steinberg::kResultTrue;
@@ -549,7 +549,7 @@ struct audio_bus_info<T>
     if(index < input_refl::size)
     {
       info.channelCount = 2;
-      setStr(info.name, u16 "Stereo In");
+      setStr(info.name, u16_str "Stereo In");
       info.busType = Steinberg::Vst::BusTypes::kMain;
 
       return Steinberg::kResultTrue;
@@ -564,7 +564,7 @@ struct audio_bus_info<T>
     if(index < output_refl::size)
     {
       info.channelCount = 2;
-      setStr(info.name, u16 "Stereo Out");
+      setStr(info.name, u16_str "Stereo Out");
       info.busType = Steinberg::Vst::BusTypes::kMain;
 
       return Steinberg::kResultTrue;
@@ -661,7 +661,7 @@ struct audio_bus_info<T>
     if(index < inputCount())
     {
       info.channelCount = 1;
-      setStr(info.name, u16 "Main In");
+      setStr(info.name, u16_str "Main In");
       info.busType = Steinberg::Vst::BusTypes::kMain;
 
       return Steinberg::kResultTrue;
@@ -676,7 +676,7 @@ struct audio_bus_info<T>
     if(index < outputCount())
     {
       info.channelCount = 1;
-      setStr(info.name, u16 "Main Out");
+      setStr(info.name, u16_str "Main Out");
       info.busType = Steinberg::Vst::BusTypes::kMain;
 
       return Steinberg::kResultTrue;
@@ -764,7 +764,7 @@ struct audio_bus_info<T>
     if(index < inputCount())
     {
       info.channelCount = 1;
-      setStr(info.name, u16 "Main In");
+      setStr(info.name, u16_str "Main In");
       info.busType = Steinberg::Vst::BusTypes::kMain;
 
       return Steinberg::kResultTrue;
@@ -779,7 +779,7 @@ struct audio_bus_info<T>
     if(index < outputCount())
     {
       info.channelCount = 1;
-      setStr(info.name, u16 "Main Out");
+      setStr(info.name, u16_str "Main Out");
       info.busType = Steinberg::Vst::BusTypes::kMain;
 
       return Steinberg::kResultTrue;
