@@ -3,6 +3,7 @@
 /* SPDX-License-Identifier: GPL-3.0-or-later OR BSL-1.0 OR CC0-1.0 OR CC-PDCC OR 0BSD */
 
 #include <avnd/common/concepts_polyfill.hpp>
+#include <avnd/common/tag.hpp>
 #include <avnd/concepts/generic.hpp>
 
 namespace avnd
@@ -14,4 +15,8 @@ type_or_value_reflection(inputs)
 type_or_value_qualification(outputs)
 type_or_value_reflection(outputs)
 
+// For symbol / selector-based environments:
+// The first argument will be the symbol
+// and it has to be std::string-like
+AVND_DEFINE_TAG(dynamic_symbol)
 }
