@@ -1,5 +1,6 @@
 #pragma once
 
+#include <version>
 /* SPDX-License-Identifier: GPL-3.0-or-later */
 
 #if defined(__APPLE__) || (defined(__clang__) && __clang_major__ <= 13)
@@ -7,3 +8,9 @@
 #else
 #define clang_buggy_consteval consteval
 #endif
+
+#if __cplusplus >= 202302L
+#define static_constexpr static constexpr
+#else
+#define static_constexpr constexpr
+#endif
