@@ -18,11 +18,14 @@
 #include <boost/system/error_code.hpp>
 
 #include <async_mqtt5/error.hpp>
+#include <async_mqtt5/logger_traits.hpp>
 #include <async_mqtt5/types.hpp>
 
+#include <async_mqtt5/detail/log_invoke.hpp>
 #include <async_mqtt5/detail/rebind_executor.hpp>
 
 #include <async_mqtt5/impl/client_service.hpp>
+#include <async_mqtt5/impl/run_op.hpp>
 #include <async_mqtt5/impl/publish_send_op.hpp>
 #include <async_mqtt5/impl/re_auth_op.hpp>
 #include <async_mqtt5/impl/subscribe_op.hpp>
@@ -39,6 +42,7 @@ namespace asio = boost::asio;
  * the stream of bytes between the Client and the Broker. The transport must be
  * ordered and lossless.
  * \tparam \__TlsContext\__ Type of the context object used in TLS/SSL connections.
+ * \tparam \__LoggerType\__ Type of object used to log events within the Client.
  *
  * \par Thread safety
  * ['Distinct objects]: safe. \n
@@ -48,7 +52,8 @@ namespace asio = boost::asio;
  */
 template <
 	typename StreamType,
-	typename TlsContext = std::monostate
+	typename TlsContext = std::monostate,
+	typename LoggerType = noop_logger
 >
 class mqtt_client {
 public:
@@ -68,9 +73,10 @@ public:
 private:
 	using stream_type = StreamType;
 	using tls_context_type = TlsContext;
+	using logger_type = LoggerType;
 
 	using client_service_type = detail::client_service<
-		stream_type, tls_context_type
+		stream_type, tls_context_type, logger_type
 	>;
 	using impl_type = std::shared_ptr<client_service_type>;
 	impl_type _impl;
@@ -80,14 +86,15 @@ public:
 	 * \brief Constructs a Client with given parameters.
 	 *
 	 * \param ex An executor that will be associated with the Client.
-	 * \param tls_context A context object used in TLS/SLL connection.
+	 * \param tls_context A context object used in TLS/SSL connection.
+	 * \param logger An object satisfying the \__LoggerType\__ concept used to log events within the Client.
 	 */
 	explicit mqtt_client(
 		const executor_type& ex,
-		TlsContext tls_context = {}
+		tls_context_type tls_context = {}, logger_type logger = {}
 	) :
 		_impl(std::make_shared<client_service_type>(
-			ex, std::move(tls_context)
+			ex, std::move(tls_context), std::move(logger)
 		))
 	{}
 
@@ -96,7 +103,8 @@ public:
 	 *
 	 * \tparam \__ExecutionContext\__ Type of a concrete execution context.
 	 * \param context Execution context whose executor will be associated with the Client.
-	 * \param tls_context A context object used in TLS/SLL connection.
+	 * \param tls_context A context object used in TLS/SSL connection.
+	 * \param logger An object satisfying the \__LoggerType\__ concept used to log events within the Client.
 	 *
 	 * \par Precondition
 	 * \code
@@ -112,9 +120,12 @@ public:
 	>
 	explicit mqtt_client(
 		ExecutionContext& context,
-		TlsContext tls_context = {}
+		tls_context_type tls_context = {}, logger_type logger = {}
 	) :
-		mqtt_client(context.get_executor(), std::move(tls_context))
+		mqtt_client(
+			context.get_executor(),
+			std::move(tls_context), std::move(logger)
+		)
 	{}
 
 	/**
@@ -124,7 +135,6 @@ public:
 	 */
 	mqtt_client(mqtt_client&&) noexcept = default;
 
-
 	/**
 	 * \brief Move assignment operator.
 	 *
@@ -153,7 +163,6 @@ public:
 		return _impl->get_executor();
 	}
 
-
 	/**
 	 * \brief Get the context object used in TLS/SSL connection.
 	 *
@@ -170,8 +179,7 @@ public:
 		typename Ctx = TlsContext,
 		std::enable_if_t<!std::is_same_v<Ctx, std::monostate>, bool> = true
 	>
-	decltype(auto) tls_context()
-	{
+	decltype(auto) tls_context() {
 		return _impl->tls_context();
 	}
 
@@ -434,7 +442,7 @@ public:
 	 * \param token Completion token that will be used to produce a
 	 * completion handler. The handler will be invoked when the operation completes.
 	 * On immediate completion, invocation of the handler will be performed in a manner
-	 * equivalent to using \__POST\__.
+	 * equivalent to using \__ASYNC_IMMEDIATE\__.
 	 *
 	 * \par Handler signature
 	 * The handler signature for this operation depends on the \ref qos_e specified:\n
@@ -527,7 +535,7 @@ public:
 	 * \param token Completion token that will be used to produce a
 	 * completion handler. The handler will be invoked when the operation completes.
 	 * On immediate completion, invocation of the handler will be performed in a manner
-	 * equivalent to using \__POST\__.
+	 * equivalent to using \__ASYNC_IMMEDIATE\__.
 	 *
 	 * \par Handler signature
 	 * The handler signature for this operation:
@@ -600,7 +608,7 @@ public:
 	 * \param token Completion token that will be used to produce a
 	 * completion handler. The handler will be invoked when the operation completes.
 	 * On immediate completion, invocation of the handler will be performed in a manner
-	 * equivalent to using \__POST\__.
+	 * equivalent to using \__ASYNC_IMMEDIATE\__.
 	 *
 	 * \par Handler signature
 	 * The handler signature for this operation:
@@ -669,7 +677,7 @@ public:
 	 * \param token Completion token that will be used to produce a
 	 * completion handler. The handler will be invoked when the operation completes.
 	 * On immediate completion, invocation of the handler will be performed in a manner
-	 * equivalent to using \__POST\__.
+	 * equivalent to using \__ASYNC_IMMEDIATE\__.
 	 *
 	 * \par Handler signature
 	 * The handler signature for this operation:
@@ -737,7 +745,7 @@ public:
 	 * \param token Completion token that will be used to produce a
 	 * completion handler. The handler will be invoked when the operation completes.
 	 * On immediate completion, invocation of the handler will be performed in a manner
-	 * equivalent to using \__POST\__.
+	 * equivalent to using \__ASYNC_IMMEDIATE\__.
 	 *
 	 * \par Handler signature
 	 * The handler signature for this operation:
@@ -863,8 +871,6 @@ public:
 	 * \param props An instance of \__DISCONNECT_PROPS\__.
 	 * \param token Completion token that will be used to produce a
 	 * completion handler. The handler will be invoked when the operation completes.
-	 * On immediate completion, invocation of the handler will be performed in a manner
-	 * equivalent to using \__POST\__.
 	 *
 	 * \par Handler signature
 	 * The handler signature for this operation:
@@ -927,8 +933,6 @@ public:
 	 *
 	 * \param token Completion token that will be used to produce a
 	 * completion handler. The handler will be invoked when the operation completes.
-	 * On immediate completion, invocation of the handler will be performed in a manner
-	 * equivalent to using \__POST\__.
 	 *
 	 * \par Handler signature
 	 * The handler signature for this operation:
@@ -972,7 +976,6 @@ public:
 
 };
 
-
 } // end namespace async_mqtt5
 
 #endif // !ASYNC_MQTT5_MQTT_CLIENT_HPP
