@@ -30,6 +30,9 @@
 #include <algorithm>
 #include <utility>
 
+CMT_PRAGMA_MSVC(warning(push))
+CMT_PRAGMA_MSVC(warning(disable : 4244))
+
 namespace kfr
 {
 inline namespace CMT_ARCH_NAME
@@ -50,20 +53,20 @@ inline namespace CMT_ARCH_NAME
         return x;                                                                                            \
     }                                                                                                        \
     template <typename T1, typename T2, size_t N, KFR_ENABLE_IF(1 + vec_rank<T1> > vec_rank<T2>)>            \
-    constexpr KFR_INTRINSIC vec<T1, N>& operator asgnop(vec<T1, N>& x, const T2& y)                          \
+    constexpr KFR_INTRINSIC vec<T1, N>& operator asgnop(vec<T1, N>& x, const T2 & y)                         \
     {                                                                                                        \
         x = intrinsics::fn(x, T1(y));                                                                        \
         return x;                                                                                            \
     }                                                                                                        \
     template <typename T1, typename T2, size_t N, typename C = std::common_type_t<T1, T2>,                   \
               KFR_ENABLE_IF(1 + vec_rank<T1> > vec_rank<T2>)>                                                \
-    constexpr KFR_INTRINSIC vec<C, N> operator op(const vec<T1, N>& x, const T2& y)                          \
+    constexpr KFR_INTRINSIC vec<C, N> operator op(const vec<T1, N>& x, const T2 & y)                         \
     {                                                                                                        \
         return intrinsics::fn(promoteto<C>(x), C(y));                                                        \
     }                                                                                                        \
     template <typename T1, typename T2, size_t N, typename C = std::common_type_t<T1, T2>,                   \
               KFR_ENABLE_IF(vec_rank<T1> < 1 + vec_rank<T2>)>                                                \
-    constexpr KFR_INTRINSIC vec<C, N> operator op(const T1& x, const vec<T2, N>& y)                          \
+    constexpr KFR_INTRINSIC vec<C, N> operator op(const T1 & x, const vec<T2, N>& y)                         \
     {                                                                                                        \
         return intrinsics::fn(C(x), promoteto<C>(y));                                                        \
     }                                                                                                        \
@@ -93,7 +96,7 @@ inline namespace CMT_ARCH_NAME
         return intrinsics::fn(x, y);                                                                         \
     }                                                                                                        \
     template <typename T1, typename T2, size_t N, KFR_ENABLE_IF(vec_rank<T1> < 1 + vec_rank<T2>)>            \
-    constexpr KFR_INTRINSIC vec<T1, N> operator op(const T1& x, const vec<T2, N>& y)                         \
+    constexpr KFR_INTRINSIC vec<T1, N> operator op(const T1 & x, const vec<T2, N>& y)                        \
     {                                                                                                        \
         return intrinsics::fn(broadcastto<T1>(x), promoteto<utype<T1>>(y));                                  \
     }                                                                                                        \
@@ -106,13 +109,13 @@ inline namespace CMT_ARCH_NAME
 #define KFR_VEC_CMP_OPERATOR(op, fn)                                                                         \
     template <typename T1, typename T2, size_t N, typename C = std::common_type_t<T1, T2>,                   \
               KFR_ENABLE_IF(1 + vec_rank<T1> > vec_rank<T2>)>                                                \
-    constexpr KFR_INTRINSIC mask<C, N> operator op(const vec<T1, N>& x, const T2& y)                         \
+    constexpr KFR_INTRINSIC mask<C, N> operator op(const vec<T1, N>& x, const T2 & y)                        \
     {                                                                                                        \
         return intrinsics::fn(promoteto<C>(x), vec<C, N>(y)).asmask();                                       \
     }                                                                                                        \
     template <typename T1, typename T2, size_t N, typename C = std::common_type_t<T1, T2>,                   \
               KFR_ENABLE_IF(vec_rank<T1> < 1 + vec_rank<T2>)>                                                \
-    constexpr KFR_INTRINSIC mask<C, N> operator op(const T1& x, const vec<T2, N>& y)                         \
+    constexpr KFR_INTRINSIC mask<C, N> operator op(const T1 & x, const vec<T2, N>& y)                        \
     {                                                                                                        \
         return intrinsics::fn(vec<C, N>(x), promoteto<C>(y)).asmask();                                       \
     }                                                                                                        \
@@ -179,12 +182,12 @@ KFR_INTRINSIC mask<C, N> operator^(const mask<T1, N>& x, const mask<T2, N>& y) C
 template <typename T, size_t N>
 KFR_INTRINSIC mask<T, N> operator~(const mask<T, N>& x) CMT_NOEXCEPT
 {
-    return ~x.asvec();
+    return mask<T, N>(~x.asvec());
 }
 template <typename T, size_t N>
 KFR_INTRINSIC mask<T, N> operator!(const mask<T, N>& x) CMT_NOEXCEPT
 {
-    return ~x.asvec();
+    return mask<T, N>(~x.asvec());
 }
 
 KFR_INTRINSIC float bitwisenot(float x) { return fbitcast(~ubitcast(x)); }
@@ -215,7 +218,7 @@ KFR_INTRINSIC std::common_type_t<T1, T2> bitwiseand(const T1& x, const T2& y)
 template <typename T>
 constexpr KFR_INTRINSIC T bitwiseand(initialvalue<T>)
 {
-    return constants<T>::allones();
+    return special_constants<T>::allones();
 }
 KFR_FN(bitwiseand)
 
@@ -228,7 +231,7 @@ KFR_INTRINSIC std::common_type_t<T1, T2> bitwiseandnot(const T1& x, const T2& y)
 template <typename T>
 constexpr inline T bitwiseandnot(initialvalue<T>)
 {
-    return constants<T>::allones();
+    return special_constants<T>::allones();
 }
 KFR_FN(bitwiseandnot)
 
@@ -594,25 +597,10 @@ constexpr KFR_INTRINSIC vec<T, N> copysign(const vec<T, N>& x, const vec<T, N>&
 }
 
 /// @brief Swap byte order
-template <typename T, size_t N, KFR_ENABLE_IF(sizeof(vec<T, N>) > 8)>
-KFR_INTRINSIC vec<T, N> swapbyteorder(const vec<T, N>& x)
-{
-    return bitcast<T>(swap<sizeof(T)>(bitcast<u8>(x)));
-}
-template <typename T, KFR_ENABLE_IF(sizeof(T) == 8)>
+template <typename T>
 KFR_INTRINSIC T swapbyteorder(const T& x)
 {
-    return reinterpret_cast<const T&>(__builtin_bswap64(reinterpret_cast<const u64&>(x)));
-}
-template <typename T, KFR_ENABLE_IF(sizeof(T) == 4)>
-KFR_INTRINSIC T swapbyteorder(const T& x)
-{
-    return reinterpret_cast<const T&>(__builtin_bswap32(reinterpret_cast<const u32&>(x)));
-}
-template <typename T, KFR_ENABLE_IF(sizeof(T) == 2)>
-KFR_INTRINSIC T swapbyteorder(const T& x)
-{
-    return reinterpret_cast<const T&>(__builtin_bswap16(reinterpret_cast<const u16&>(x)));
+    return bitcast_anything<T>(swap<sizeof(deep_subtype<T>)>(bitcast_anything<vec<u8, sizeof(T)>>(x)));
 }
 KFR_FN(swapbyteorder)
 
@@ -643,7 +631,7 @@ KFR_INTRINSIC vec<T, N> negodd(const vec<T, N>& x)
 template <typename T, size_t N1, size_t... Ns>
 vec<vec<T, sizeof...(Ns) + 1>, N1> packtranspose(const vec<T, N1>& x, const vec<T, Ns>&... rest)
 {
-    const vec<T, N1*(sizeof...(Ns) + 1)> t = transpose<N1>(concat(x, rest...));
+    const vec<T, N1 * (sizeof...(Ns) + 1)> t = transpose<N1>(concat(x, rest...));
     return t.v;
 }
 
@@ -659,3 +647,5 @@ KFR_I_CE vec<bit<T>, N>::vec(const base& v) CMT_NOEXCEPT
 
 } // namespace CMT_ARCH_NAME
 } // namespace kfr
+
+CMT_PRAGMA_MSVC(warning(pop))
