@@ -1,6 +1,6 @@
 #pragma once
 
-#if defined(MSC_VER)
+#if defined(_MSC_VER)
   #define NOMINMAX 1
   #define WIN32_LEAN_AND_MEAN
 #endif
@@ -62,3 +62,9 @@ using midi_bytes = std::vector<unsigned char>;
 #else
   #define LIBREMIDI_INLINE
 #endif
+
+#if __cpp_contracts >= 202502L
+  #define LIBREMIDI_PRECONDITION(...) pre(__VA_ARGS__)
+#else
+  #define LIBREMIDI_PRECONDITION(...)
+#endif
