@@ -48,8 +48,8 @@ using http_request = ossia::net::http_get_request<http_answer, http_error>;
 struct http_client_context
 {
   std::thread thread;
-  boost::asio::io_service context;
-  std::shared_ptr<boost::asio::io_service::work> worker;
+  boost::asio::io_context context;
+  std::shared_ptr<boost::asio::executor_work_guard<boost::asio::io_context::executor_type>> worker;
 };
 /*
 auto wait_for(std::future<void>& fut, std::chrono::milliseconds dur)
@@ -629,13 +629,13 @@ void oscquery_mirror_protocol::init()
     }
   }
 
-  http_send_message("/?HOST_INFO");
+  http_send_message("/?HOST_INFO=1");
   m_oscServer->run();
 }
 
 void oscquery_mirror_protocol::start_http()
 {
-  m_http->worker = std::make_shared<boost::asio::io_service::work>(m_http->context);
+  m_http->worker = std::make_shared<boost::asio::executor_work_guard<boost::asio::io_context::executor_type>>(m_http->context.get_executor());
   m_http->thread = std::thread([this] {
     ossia::set_thread_name("ossia oscq http");
     m_http->context.run();
