@@ -25,6 +25,10 @@ Distributed under the Boost Software License, Version 1.0.
 #ifndef LLFIO_BYTE_SOCKET_HANDLE_H
 #define LLFIO_BYTE_SOCKET_HANDLE_H
 
+#ifndef LLFIO_DISABLE_DEPRECATION_WARNINGS
+#warning "Networking support is deprecated and scheduled for removal soon"
+#endif
+
 #include "byte_io_handle.hpp"
 
 struct sockaddr;
@@ -41,6 +45,11 @@ struct sockaddr_in6;
 #pragma warning(disable : 4661)  // missing implementation
 #endif
 
+#if defined(__GNUC__) && !defined(__clang__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Woverloaded-virtual="
+#endif
+
 LLFIO_V2_NAMESPACE_EXPORT_BEGIN
 
 class byte_socket_handle;
@@ -76,6 +85,8 @@ namespace ip
   /*! \class address
   \brief A version independent IP address.
 
+  \warning This is deprecated and scheduled for removal in 2025.
+
   This is inspired by `asio::ip::address`, but it also adds `port()` from `asio::ip::endpoint`
   and a few other observer member functions i.e. it fuses ASIO's many types into one.
 
@@ -229,6 +240,8 @@ namespace ip
   /*! \brief Retrieve a list of potential `address` for a given name and service e.g.
   "www.google.com" and "https" optionally within a bounded deadline.
 
+  \warning This is deprecated and scheduled for removal in 2025.
+
   The object returned by this function can take many seconds to become ready as multiple network requests may
   need to be made. The deadline can be used to bound execution times -- like in a few
   other places in LLFIO, this deadline does not cause timed out errors, rather it aborts
@@ -283,9 +296,15 @@ namespace ip
     static LLFIO_HEADERS_ONLY_MEMFUNC_SPEC address_v4 loopback() noexcept;
   };
   //! Make an `address_v4`
-  inline result<address_v4> make_address_v4(const address_v4::bytes_type &bytes, uint16_t port = 0) noexcept { return address_v4(bytes, port); }
+  inline result<address_v4> make_address_v4(const address_v4::bytes_type &bytes, uint16_t port = 0) noexcept
+  {
+    return address_v4(bytes, port);
+  }
   //! Make an `address_v4`
-  inline result<address_v4> make_address_v4(const address_v4::uint_type &bytes, uint16_t port = 0) noexcept { return address_v4(bytes, port); }
+  inline result<address_v4> make_address_v4(const address_v4::uint_type &bytes, uint16_t port = 0) noexcept
+  {
+    return address_v4(bytes, port);
+  }
 
   //! Make an `address_v6`
   LLFIO_HEADERS_ONLY_FUNC_SPEC result<address_v6> make_address_v6(string_view str) noexcept;
@@ -339,6 +358,8 @@ namespace ip
 /*! \class byte_socket_handle
 \brief A handle to a byte-orientated socket-like entity.
 
+\warning This is deprecated and scheduled for removal in 2025.
+
 This handle, or subclasses thereof, may refer to:
 
 - a BSD socket in the kernel configured for TCP.
@@ -781,19 +802,19 @@ template <class Base, class SocketType> struct listening_socket_handle_buffer_ty
     constexpr const_iterator cend() const noexcept { return _sock + 1; }
 
     //! The socket referenced by the buffers
-    const buffer_type &connected_socket() const &noexcept
+    const buffer_type &connected_socket() const & noexcept
     {
       assert(_sock != nullptr);
       return *_sock;
     }
     //! The socket referenced by the buffers
-    buffer_type &connected_socket() &noexcept
+    buffer_type &connected_socket() & noexcept
     {
       assert(_sock != nullptr);
       return *_sock;
     }
     //! The socket and its connected address referenced by the buffers
-    buffer_type connected_socket() &&noexcept
+    buffer_type connected_socket() && noexcept
     {
       assert(_sock != nullptr);
       return std::move(*_sock);
@@ -1043,7 +1064,7 @@ public:
   //! \brief Convenience function defaulting `flag::multiplexable` set.
   LLFIO_MAKE_FREE_FUNCTION
   static result<listening_byte_socket_handle> multiplexable_listening_byte_socket(ip::family _family, mode _mode = mode::write, caching _caching = caching::all,
-                                                                             flag flags = flag::multiplexable) noexcept
+                                                                                  flag flags = flag::multiplexable) noexcept
   {
     return listening_byte_socket(_family, _mode, _caching, flags);
   }
@@ -1110,7 +1131,10 @@ template <> struct construct<listening_byte_socket_handle>
   byte_socket_handle::mode _mode = byte_socket_handle::mode::write;
   byte_socket_handle::caching _caching = byte_socket_handle::caching::all;
   byte_socket_handle::flag flags = byte_socket_handle::flag::none;
-  result<listening_byte_socket_handle> operator()() const noexcept { return listening_byte_socket_handle::listening_byte_socket(family, _mode, _caching, flags); }
+  result<listening_byte_socket_handle> operator()() const noexcept
+  {
+    return listening_byte_socket_handle::listening_byte_socket(family, _mode, _caching, flags);
+  }
 };
 
 // BEGIN make_free_functions.py
@@ -1128,4 +1152,8 @@ LLFIO_V2_NAMESPACE_END
 #pragma warning(pop)
 #endif
 
+#if defined(__GNUC__) && !defined(__clang__)
+#pragma GCC diagnostic pop
+#endif
+
 #endif
