@@ -1,5 +1,5 @@
 /* A handle to a directory
-(C) 2017-2021 Niall Douglas <http://www.nedproductions.biz/> (20 commits)
+(C) 2017-2024 Niall Douglas <http://www.nedproductions.biz/> (20 commits)
 File Created: Aug 2017
 
 
@@ -26,6 +26,7 @@ Distributed under the Boost Software License, Version 1.0.
 #define LLFIO_DIRECTORY_HANDLE_H
 
 #include "path_discovery.hpp"
+#include "quickcpplib/bitfield.hpp"
 #include "stat.hpp"
 
 #include <memory>  // for unique_ptr
@@ -69,6 +70,16 @@ an allocation-free cycle per directory enumeration.
 class LLFIO_DECL directory_handle : public path_handle, public fs_handle
 {
   LLFIO_HEADERS_ONLY_VIRTUAL_SPEC const handle &_get_handle() const noexcept final { return *this; }
+  LLFIO_HEADERS_ONLY_VIRTUAL_SPEC result<void> _replace_handle(handle &&o_) noexcept override
+  {
+    auto &o = static_cast<decltype(*this) &>(o_);
+    if(_v.behaviour != o._v.behaviour)
+    {
+      return errc::invalid_argument;
+    }
+    _v.swap(o._v);
+    return success();
+  }
 
   mutable std::atomic<unsigned> _lock{0};  // used to serialise read()
 
@@ -104,12 +115,22 @@ public:
     stat_t::want metadata() const noexcept { return _metadata; }
     //! Whether the directory was entirely read or not into any buffers supplied.
     bool done() const noexcept { return _done; }
+    //! Whether the enumeration is an atomically consistent snapshot or not
+    bool is_snapshot() const noexcept { return _snapshot; }
 
+  private:
+    struct _implict_span_constructor_tag
+    {
+    };
+
+  public:
     using _base::_base;
     buffers_type() = default;
-    //! Implicit construction from a span
-    /* constexpr */ buffers_type(span<buffer_type> v)  // NOLINT TODO FIXME Make this constexpr when span becomes constexpr. SAME for move constructor below
-    : _base(v)
+    //! Constructor taking any type acceptable to `span`.
+    LLFIO_TEMPLATE(class T)
+    LLFIO_TREQUIRES(LLFIO_TPRED(!std::is_same<typename std::decay<T>::type, buffers_type>::value && std::is_constructible<span<buffer_type>, T>::value))
+    constexpr buffers_type(T &&s, _implict_span_constructor_tag = {}) noexcept
+        : _base(std::forward<T>(s))
     {
     }
     //! Construct from a span, using a kernel buffer from a preceding `buffers_type`.
@@ -125,7 +146,12 @@ public:
     }
     ~buffers_type() = default;
     //! Move constructor
-    /* constexpr */ buffers_type(buffers_type &&o) noexcept : _base(std::move(o)), _kernel_buffer(std::move(o._kernel_buffer)), _kernel_buffer_size(o._kernel_buffer_size), _metadata(o._metadata), _done(o._done)
+    /* constexpr */ buffers_type(buffers_type &&o) noexcept
+        : _base(std::move(o))
+        , _kernel_buffer(std::move(o._kernel_buffer))
+        , _kernel_buffer_size(o._kernel_buffer_size)
+        , _metadata(o._metadata)
+        , _done(o._done)
     {
       static_cast<_base &>(o) = {};
       o._kernel_buffer_size = 0;
@@ -161,9 +187,15 @@ public:
     void _resize(size_t l) { *static_cast<span<buffer_type> *>(this) = this->subspan(0, l); }
     stat_t::want _metadata{stat_t::want::none};
     bool _done{false};
+    bool _snapshot{true};
   };
+  //! Flags for how to enumerate directory entries
+  QUICKCPPLIB_BITFIELD_BEGIN_T(flags, uint8_t){
+  none = 0u,                      //!< No flags
+  permit_racy_reads = (1u << 0u)  //!< Do not error out if a atomic snapshot cannot be performed
+  } QUICKCPPLIB_BITFIELD_END(flags) using _flags_type = flags;
   //! How to do deleted file elimination on Windows
-  enum class filter
+  enum class filter : uint8_t
   {
     none,        //!< Do no filtering at all
     fastdeleted  //!< For Windows without POSIX delete semantics, filter out LLFIO deleted files based on their filename (fast and fairly reliable)
@@ -173,6 +205,7 @@ public:
   {
     buffers_type buffers{};
     path_view_type glob{};
+    _flags_type flags{_flags_type::none};
     filter filtering{filter::fastdeleted};
     span<char> kernelbuffer{};
 
@@ -192,6 +225,25 @@ public:
         , kernelbuffer(_kernelbuffer)
     {
     }
+    /*! Construct a request to enumerate a directory with optionally specified kernel buffer.
+
+    \param _buffers The buffers to fill with enumerated directory entries.
+    \param _flags What flags to apply to the enumeration.
+    \param _glob An optional shell glob by which to filter the items filled. Done kernel side on Windows, user side on POSIX.
+    \param _filtering Whether to filter out fake-deleted files on Windows or not.
+    \param _kernelbuffer A buffer to use for the kernel to fill. If left defaulted, a kernel buffer
+    is allocated internally and returned in the buffers returned which needs to not be destructed until one
+    is no longer using any items within (leafnames are views onto the original kernel data).
+    */
+    /*constexpr*/ io_request(buffers_type _buffers, _flags_type _flags, path_view_type _glob = {}, filter _filtering = filter::fastdeleted,
+                             span<char> _kernelbuffer = {})
+        : buffers(std::move(_buffers))
+        , glob(_glob)
+        , flags(_flags)
+        , filtering(_filtering)
+        , kernelbuffer(_kernelbuffer)
+    {
+    }
   };
 
 
@@ -210,11 +262,19 @@ public:
   {
   }
   //! Implicit move construction of directory_handle permitted
-  constexpr directory_handle(directory_handle &&o) noexcept : path_handle(std::move(o)), fs_handle(std::move(o)) {}
+  constexpr directory_handle(directory_handle &&o) noexcept
+      : path_handle(std::move(o))
+      , fs_handle(std::move(o))
+  {
+  }
   //! No copy construction (use `clone()`)
   directory_handle(const directory_handle &) = delete;
   //! Explicit conversion from handle permitted
-  explicit constexpr directory_handle(handle &&o, dev_t devid, ino_t inode) noexcept : path_handle(std::move(o)), fs_handle(devid, inode) {}
+  explicit constexpr directory_handle(handle &&o, dev_t devid, ino_t inode) noexcept
+      : path_handle(std::move(o))
+      , fs_handle(devid, inode)
+  {
+  }
   //! Move assignment of directory_handle permitted
   directory_handle &operator=(directory_handle &&o) noexcept
   {
@@ -242,7 +302,9 @@ public:
   \errors Any of the values POSIX open() or CreateFile() can return.
   */
   LLFIO_MAKE_FREE_FUNCTION
-  static LLFIO_HEADERS_ONLY_MEMFUNC_SPEC result<directory_handle> directory(const path_handle &base, path_view_type path, mode _mode = mode::read, creation _creation = creation::open_existing, caching _caching = caching::all, flag flags = flag::none) noexcept;
+  static LLFIO_HEADERS_ONLY_MEMFUNC_SPEC result<directory_handle> directory(const path_handle &base, path_view_type path, mode _mode = mode::read,
+                                                                            creation _creation = creation::open_existing, caching _caching = caching::all,
+                                                                            flag flags = flag::none) noexcept;
   /*! Create a directory handle creating a uniquely named file on a path.
   The file is opened exclusively with `creation::only_if_not_exist` so it
   will never collide with nor overwrite any existing entry.
@@ -250,7 +312,8 @@ public:
   \errors Any of the values POSIX open() or CreateFile() can return.
   */
   LLFIO_MAKE_FREE_FUNCTION
-  static inline result<directory_handle> uniquely_named_directory(const path_handle &dirpath, mode _mode = mode::write, caching _caching = caching::temporary, flag flags = flag::none) noexcept
+  static inline result<directory_handle> uniquely_named_directory(const path_handle &dirpath, mode _mode = mode::write, caching _caching = caching::temporary,
+                                                                  flag flags = flag::none) noexcept
   {
     try
     {
@@ -278,7 +341,9 @@ public:
   \errors Any of the values POSIX open() or CreateFile() can return.
   */
   LLFIO_MAKE_FREE_FUNCTION
-  static inline result<directory_handle> temp_directory(path_view_type name = path_view_type(), mode _mode = mode::write, creation _creation = creation::if_needed, caching _caching = caching::all, flag flags = flag::none) noexcept
+  static inline result<directory_handle> temp_directory(path_view_type name = path_view_type(), mode _mode = mode::write,
+                                                        creation _creation = creation::if_needed, caching _caching = caching::all,
+                                                        flag flags = flag::none) noexcept
   {
     auto &tempdirh = path_discovery::storage_backed_temporary_files_directory();
     return name.empty() ? uniquely_named_directory(tempdirh, _mode, _caching, flags) : directory(tempdirh, name, _mode, _creation, _caching, flags);
@@ -296,7 +361,9 @@ public:
     LLFIO_LOG_FUNCTION_CALL(this);
     if(_.flags & flag::unlink_on_first_close)
     {
-      auto ret = unlink();
+      // if called from the destructor, no virtual dispatch will happen
+      // which is expected/fine in this case
+      auto ret = unlink();  // NOLINT(clang-analyzer-optin.cplusplus.VirtualCall)
       if(!ret)
       {
         // File may have already been deleted, if so ignore
@@ -320,7 +387,8 @@ public:
   \mallocs On POSIX if changing the mode, we must loop calling `current_path()` and
   trying to open the path returned. Thus many allocations may occur.
   */
-  LLFIO_HEADERS_ONLY_VIRTUAL_SPEC result<directory_handle> reopen(mode mode_ = mode::unchanged, caching caching_ = caching::unchanged, deadline d = std::chrono::seconds(30)) const noexcept;
+  LLFIO_HEADERS_ONLY_VIRTUAL_SPEC result<directory_handle> reopen(mode mode_ = mode::unchanged, caching caching_ = caching::unchanged,
+                                                                  deadline d = std::chrono::seconds(30)) const noexcept;
   LLFIO_DEADLINE_TRY_FOR_UNTIL(reopen)
 
   /*! Return a copy of this directory handle, but as a path handle.
@@ -340,12 +408,14 @@ public:
 
   /*! Fill the buffers type with as many directory entries as will fit into any optionally supplied buffer.
   This operation returns a **snapshot**, without races, of the directory contents at the moment of the
-  call.
+  call, unless `flags::permit_racy_reads` is set.
 
   \return Returns the buffers filled, what metadata was filled in and whether the entire directory
   was read or not. You should *always* examine `.metadata()` for the metadata you are about to use,
   fetching it with `stat_t::fill()` if not yet present.
   \param req A buffer fill (directory enumeration) request.
+  \param d An optional deadline by which the i/o must complete, else it is cancelled.
+  Note function may return significantly after this deadline if the i/o takes long to cancel.
   \errors todo
   \mallocs If the `kernelbuffer` parameter is set in the request, no memory allocations.
   If unset, at least one memory allocation, possibly more is performed. MAKE SURE you reuse the
@@ -391,10 +461,15 @@ inline void swap(directory_handle &self, directory_handle &o) noexcept
 
 \errors Any of the values POSIX open() or CreateFile() can return.
 */
-inline result<directory_handle> directory(const path_handle &base, directory_handle::path_view_type path, directory_handle::mode _mode = directory_handle::mode::read, directory_handle::creation _creation = directory_handle::creation::open_existing, directory_handle::caching _caching = directory_handle::caching::all,
+inline result<directory_handle> directory(const path_handle &base, directory_handle::path_view_type path,
+                                          directory_handle::mode _mode = directory_handle::mode::read,
+                                          directory_handle::creation _creation = directory_handle::creation::open_existing,
+                                          directory_handle::caching _caching = directory_handle::caching::all,
                                           directory_handle::flag flags = directory_handle::flag::none) noexcept
 {
-  return directory_handle::directory(std::forward<decltype(base)>(base), std::forward<decltype(path)>(path), std::forward<decltype(_mode)>(_mode), std::forward<decltype(_creation)>(_creation), std::forward<decltype(_caching)>(_caching), std::forward<decltype(flags)>(flags));
+  return directory_handle::directory(std::forward<decltype(base)>(base), std::forward<decltype(path)>(path), std::forward<decltype(_mode)>(_mode),
+                                     std::forward<decltype(_creation)>(_creation), std::forward<decltype(_caching)>(_caching),
+                                     std::forward<decltype(flags)>(flags));
 }
 /*! Create a directory handle creating a randomly named file on a path.
 The file is opened exclusively with `creation::only_if_not_exist` so it
@@ -402,9 +477,12 @@ will never collide with nor overwrite any existing entry.
 
 \errors Any of the values POSIX open() or CreateFile() can return.
 */
-inline result<directory_handle> uniquely_named_directory(const path_handle &dirpath, directory_handle::mode _mode = directory_handle::mode::write, directory_handle::caching _caching = directory_handle::caching::temporary, directory_handle::flag flags = directory_handle::flag::none) noexcept
+inline result<directory_handle> uniquely_named_directory(const path_handle &dirpath, directory_handle::mode _mode = directory_handle::mode::write,
+                                                         directory_handle::caching _caching = directory_handle::caching::temporary,
+                                                         directory_handle::flag flags = directory_handle::flag::none) noexcept
 {
-  return directory_handle::uniquely_named_directory(std::forward<decltype(dirpath)>(dirpath), std::forward<decltype(_mode)>(_mode), std::forward<decltype(_caching)>(_caching), std::forward<decltype(flags)>(flags));
+  return directory_handle::uniquely_named_directory(std::forward<decltype(dirpath)>(dirpath), std::forward<decltype(_mode)>(_mode),
+                                                    std::forward<decltype(_caching)>(_caching), std::forward<decltype(flags)>(flags));
 }
 /*! Create a directory handle creating the named directory on some path which
 the OS declares to be suitable for temporary files.
@@ -414,10 +492,15 @@ parameter is ignored.
 
 \errors Any of the values POSIX open() or CreateFile() can return.
 */
-inline result<directory_handle> temp_directory(directory_handle::path_view_type name = directory_handle::path_view_type(), directory_handle::mode _mode = directory_handle::mode::write, directory_handle::creation _creation = directory_handle::creation::if_needed,
-                                               directory_handle::caching _caching = directory_handle::caching::all, directory_handle::flag flags = directory_handle::flag::none) noexcept
+inline result<directory_handle> temp_directory(directory_handle::path_view_type name = directory_handle::path_view_type(),
+                                               directory_handle::mode _mode = directory_handle::mode::write,
+                                               directory_handle::creation _creation = directory_handle::creation::if_needed,
+                                               directory_handle::caching _caching = directory_handle::caching::all,
+                                               directory_handle::flag flags = directory_handle::flag::none) noexcept
 {
-  return directory_handle::temp_directory(std::forward<decltype(name)>(name), std::forward<decltype(_mode)>(_mode), std::forward<decltype(_creation)>(_creation), std::forward<decltype(_caching)>(_caching), std::forward<decltype(flags)>(flags));
+  return directory_handle::temp_directory(std::forward<decltype(name)>(name), std::forward<decltype(_mode)>(_mode),
+                                          std::forward<decltype(_creation)>(_creation), std::forward<decltype(_caching)>(_caching),
+                                          std::forward<decltype(flags)>(flags));
 }
 // END make_free_functions.py
 
