@@ -27,6 +27,7 @@ clone_addon https://github.com/ossia/iscore-addon-network
 clone_addon https://github.com/ossia/score-addon-synthimi
 clone_addon https://github.com/ossia/score-addon-jk
 clone_addon https://github.com/ossia/score-addon-puara
+clone_addon https://github.com/ossia/GBAP
 
 CI_PLATFORM="${1:-DEFAULT}"
 
@@ -41,10 +42,7 @@ then
   clone_addon https://github.com/ossia/score-addon-led
   clone_addon https://github.com/ossia/score-addon-spatgris
   clone_addon https://github.com/ossia/score-addon-hdf5
-fi
-
-if [[ ! -d score-addon-onnx ]]; then
-  git clone --recursive -j16 https://github.com/ossia/score-addon-onnx
+  clone_addon https://github.com/ossia/score-addon-onnx
 fi
 
 )
