@@ -5,8 +5,9 @@ dnf -y install https://download1.rpmfusion.org/free/fedora/rpmfusion-free-releas
 dnf -y install https://download1.rpmfusion.org/nonfree/fedora/rpmfusion-nonfree-release-$(rpm -E %fedora).noarch.rpm
 
 # TODO fix SDL2-devel SDL2-static -fPIC issue
-
-dnf -y --allowerasing install \
+dnf -y update # Needed for dnf-5 does not know allowerasing error
+dnf -y install dnf5-plugins
+dnf -y install --allowerasing \
      clang \
      cmake ninja-build \
      ffmpeg-devel \
@@ -22,7 +23,6 @@ dnf -y --allowerasing install \
      bluez-libs-devel \
      qt6-qtbase-devel \
      qt6-qtbase-private-devel \
-     qt6-qt5compat-devel \
      qt6-qtscxml-devel \
      qt6-qtshadertools-devel \
      qt6-qtserialport-devel \
@@ -30,6 +30,7 @@ dnf -y --allowerasing install \
      qt6-qtwebsockets-devel \
      qt6-qtdeclarative-devel \
      qt6-qtdeclarative-private-devel \
-     pipewire-devel
+     pipewire-devel \
+     zlib-ng-compat-static zlib-ng-compat-devel
 
 source ci/common.deps.sh
