@@ -13,6 +13,6 @@
 # lv2 suil lilv
 
 
-if c++ --version | grep clang; then 
+# if c++ --version | grep clang; then 
   source ci/common.deps.sh
-fi
\ No newline at end of file
+#fi
