@@ -17,6 +17,9 @@ ResnetDetector::~ResnetDetector() = default;
 
 void ResnetDetector::operator()()
 {
+  if (!available)
+    return;
+
   auto& in_tex = inputs.image.texture;
   if (!in_tex.changed)
     return;
@@ -35,6 +38,7 @@ void ResnetDetector::operator()()
       in_tex.height,
       this->inputs.resolution.value.x,
       this->inputs.resolution.value.y,
+      storage,
       true);
   Ort::Value tt[1] = {std::move(t.value)};
 
@@ -42,9 +46,8 @@ void ResnetDetector::operator()()
   Ort::Value out_tt[1]{Ort::Value{nullptr}};
   ctx.infer(spec, tt, out_tt);
 
-  static const Resnet r;
   outputs.detection.value.clear();
-  r.processOutput(
+  resnet.processOutput(
       spec,
       out_tt,
       reinterpret_cast<std::vector<OnnxModels::Resnet::recognition_type>&>(
@@ -55,6 +58,6 @@ void ResnetDetector::operator()()
          .width = in_tex.width,
          .height = in_tex.height,
          .changed = true};
+  std::swap(storage, t.storage);
 }
-
 }
