@@ -10,7 +10,7 @@ class GestureRecognizer
 {
 public:
   halp_meta(name, "Gesture recognizer")
-  halp_meta(category, "Gestures")
+  halp_meta(category, "Control/Gestures")
   halp_meta(c_name, "puara_gestures")
   halp_meta(
       author,
