@@ -37,12 +37,16 @@ extern "C" void sincos(double x, double* sin, double* cos)
 
 #include <ossia/detail/config.hpp>
 
+#include <ossia/detail/disable_fpe.hpp>
 #include <ossia/detail/thread.hpp>
 
 #include <QApplication>
+#include <QDir>
 #include <QItemSelection>
 #include <QPixmapCache>
+#include <QStandardPaths>
 #include <QSurfaceFormat>
+#include <QTimer>
 #include <qnamespace.h>
 
 #include <clocale>
@@ -109,10 +113,59 @@ void disableAppRestore()
   CFPreferencesAppSynchronize(kCFPreferencesCurrentApplication);
 }
 
+void ensureDyldPath()
+{
+  auto e = qEnvironmentVariable("DYLD_LIBRARY_PATH");
+  if(e.isEmpty())
+  {
+    return;
+  }
+  else
+  {
+    fprintf(
+        stderr,
+        "Fatal error: DYLD_LIBRARY_PATH must not be set on macOS.\n"
+        "See https://github.com/ossia/score/issues/1711\n\n"
+        "If using Qt Creator, simply go in Projects and\n"
+        "uncheck the 'Add library search path to DYLD_LIBRARY_PATH and "
+        "DYLD_FRAMEWORK_PATH'\n"
+        "checkbox on the execution tab.\n\n"
+        "Current DYLD_LIBRARY_PATH: %s",
+        e.toStdString().c_str());
+
+    // If you see this comment, you are allowed to remove it on your dev
+    // build but be aware that you will likely hit very spurious random
+    // crashes, for instance when a PNG gets loaded or when opening a file
+    // dialog
+    exit(1);
+  }
+}
+
 // Defined in mac_main.m
 extern "C" void disableAppNap();
 #endif
 
+extern "C" {
+Q_DECL_EXPORT short NvOptimusEnablement = 1;
+Q_DECL_EXPORT int AmdPowerXpressRequestHighPerformance = 1;
+}
+
+static void setup_gpu()
+{
+#if defined(__linux__)
+  if(QDir{"/proc/driver/nvidia/gpus"}
+         .entryList(QDir::Dirs | QDir::NoDotAndDotDot)
+         .count()
+     > 0)
+  {
+    if(!qEnvironmentVariableIsSet("__GLX_VENDOR_LIBRARY_NAME"))
+      qputenv("__GLX_VENDOR_LIBRARY_NAME", "nvidia");
+    if(!qEnvironmentVariableIsSet("__NV_PRIME_RENDER_OFFLOAD"))
+      qputenv("__NV_PRIME_RENDER_OFFLOAD", "1");
+  }
+#endif
+}
+
 static void setup_x11(int argc, char** argv)
 {
 #if defined(__linux__)
@@ -168,22 +221,62 @@ static void setup_x11(int argc, char** argv)
 #endif
 }
 
+#if defined(__linux__)
+extern "C" {
+enum SuilArg
+{
+  SUIL_ARG_NONE
+};
+using suil_init_t = void (*)(int* argc, char*** argv, SuilArg key, ...);
+}
+#endif
 static void setup_suil()
 {
 #if defined(__linux__)
-  enum SuilArg
+  // 1. In the appimage case we have to tell suil that libsuil_x11_in_qt6.so is
+  // nrelative to the executable
+  if(qEnvironmentVariableIsEmpty("SUIL_MODULE_DIR"))
   {
-    SUIL_ARG_NONE
-  };
-  using suil_init_t = void (*)(int* argc, char*** argv, SuilArg key, ...);
+    auto path = ossia::get_exe_path();
+    auto last_slash =
+#if defined(_WIN32)
+        path.find_last_of('\\');
+#else
+        path.find_last_of('/');
+#endif
+    if(last_slash == std::string::npos)
+      return;
 
+    path = path.substr(0, last_slash);
+    if(path.ends_with("/bin"))
+      path.resize(path.size() - 3);
+
+    path += "/lib/suil-0";
+    if(QDir{}.exists(QString::fromStdString(path)))
+    {
+      qputenv("SUIL_MODULE_DIR", path.c_str());
+    }
+  }
+
+  // 2. Init suil if necessary
   if(auto lib = dlopen("libsuil-0.so.0", RTLD_LAZY | RTLD_LOCAL))
+  {
     if(auto sym = reinterpret_cast<suil_init_t>(dlsym(lib, "suil_init")))
     {
       static int argc{0};
       static char** argv{nullptr};
       sym(&argc, &argv, SUIL_ARG_NONE);
     }
+  }
+  else if(auto self = dlopen(nullptr, RTLD_LAZY | RTLD_LOCAL))
+  {
+    if(auto sym = reinterpret_cast<suil_init_t>(dlsym(self, "suil_init")))
+    {
+      static int argc{0};
+      static char** argv{nullptr};
+      sym(&argc, &argv, SUIL_ARG_NONE);
+    }
+  }
 #endif
 }
 
@@ -291,28 +384,6 @@ struct increase_timer_precision
   }
 };
 
-static void disable_denormals()
-{
-#if defined(__EMSCRIPTEN__)
-  // do nothing
-#elif defined(__SSE3__)
-  // See https://en.wikipedia.org/wiki/Denormal_number
-  // and
-  // http://stackoverflow.com/questions/9314534/why-does-changing-0-1f-to-0-slow-down-performance-by-10x
-  _MM_SET_DENORMALS_ZERO_MODE(_MM_DENORMALS_ZERO_ON);
-  _MM_SET_FLUSH_ZERO_MODE(_MM_FLUSH_ZERO_ON);
-#elif defined(__arm__)
-  int x;
-  asm("vmrs %[result],FPSCR \r\n"
-      "bic %[result],%[result],#16777216 \r\n"
-      "vmsr FPSCR,%[result]"
-      : [result] "=r"(x)
-      :
-      :);
-  printf("ARM FPSCR: %08x\n", x);
-#endif
-}
-
 static void setup_faust_path()
 {
   if(!qEnvironmentVariableIsEmpty("FAUST_LIB_PATH"))
@@ -356,9 +427,9 @@ static void setup_opengl(bool& enable_opengl_ui)
     return;
 
 #ifndef QT_NO_OPENGL
-#if defined(__arm__)
+#if (defined(__arm__) || defined(__aarch64__)) && !defined(_WIN32) && !defined(__APPLE__)
   QSurfaceFormat fmt = QSurfaceFormat::defaultFormat();
-  fmt.setProfile(QSurfaceFormat::CoreProfile);
+  fmt.setRenderableType(QSurfaceFormat::OpenGLES);
   fmt.setSwapInterval(1);
   fmt.setMajorVersion(3);
   fmt.setMinorVersion(2);
@@ -463,13 +534,12 @@ static void setup_locale()
 
 static void setup_app_flags()
 {
+  qputenv("QT_NO_GLIB", "1");
   qputenv("QSG_USE_SIMPLE_ANIMATION_DRIVER", "1");
   qputenv("QSG_RENDER_LOOP", "basic");
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
   // Consistency in looks across macOS, Windows (which prevents the horrible 125% scaling) and Linux
   // FIXME in Qt 6 this is entirely broken... https://bugreports.qt.io/browse/QTBUG-103225
-  qputenv("QT_FONT_DPI", "96");
-#endif
+  // qputenv("QT_FONT_DPI", "96");
 
   if(!qEnvironmentVariableIsSet("QT_SUBPIXEL_AA_TYPE"))
     qputenv("QT_SUBPIXEL_AA_TYPE", "RGB");
@@ -489,14 +559,18 @@ static void setup_app_flags()
   // Else things look horrible on KDE plasma, etc
   qputenv("QT_AUTO_SCREEN_SCALE_FACTOR", "1");
 
-  // https://github.com/ossia/score/issues/953
-  // https://github.com/ossia/score/issues/1046
-  QCoreApplication::setAttribute(Qt::AA_DontUseNativeDialogs);
+  if(!qEnvironmentVariableIsSet("FLATPAK_ID"))
+  {
+    // https://github.com/ossia/score/issues/953
+    // https://github.com/ossia/score/issues/1046
+    // https://github.com/ossia/score/issues/1725 for the flatpak reenablement
+    QCoreApplication::setAttribute(Qt::AA_DontUseNativeDialogs, true);
+  }
   QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts, false);
 #endif
 }
 
-#if FFTW3_HAS_THREADS
+#if FFTW_HAS_THREADS
 #include <fftw3.h>
 static void setup_fftw()
 {
@@ -536,9 +610,6 @@ static void setup_limits()
   }
 #endif
 }
-#include <QDir>
-#include <QStandardPaths>
-#include <QTimer>
 namespace
 {
 struct failsafe
@@ -595,16 +666,15 @@ int main(int argc, char** argv)
 #if defined(__APPLE__)
   disableAppRestore();
   disableAppNap();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-  qputenv("QT_MAC_WANTS_LAYER", "1");
-#endif
+  ensureDyldPath();
+  // FIXME broken in qt6 qputenv("QT_MAC_WANTS_LAYER", "1");
 #endif
 
   setup_limits();
+  setup_gpu();
   setup_x11(argc, argv);
   setup_gtk();
   setup_suil();
-  disable_denormals();
   setup_faust_path();
   setup_locale();
   setup_app_flags();
@@ -626,7 +696,7 @@ int main(int argc, char** argv)
   if(failsafe)
     app.appSettings.opengl = false;
 
-#if defined(__linux__)
+#if defined(__linux__) && !(defined(__arm__) || defined(__aarch64__))
   // On linux under offscreen, etc it crashes inside
   // QOffscreenSurface::create
   // so we check if we set --no-opengl explicitly
@@ -652,6 +722,7 @@ int main(int argc, char** argv)
   });*/
 #endif
 
+  ossia::disable_fpe();
   int res = app.exec();
 
   return res;
