@@ -15,9 +15,10 @@ void GraphicsTabLayout::addTab(QString tab)
 void GraphicsTabLayout::layout()
 {
   const auto& items = this->childItems();
+  updateChildrenRects(items);
   m_pages.assign(items.begin(), items.end());
 
-  SCORE_ASSERT(items.size() == m_tabs.size());
+  SCORE_ASSERT(items.size() == std::ssize(m_tabs));
   const int N = items.size();
 
   // Create a button for each item
