@@ -12,13 +12,14 @@ QStringList list_ipv4() noexcept
 {
 #ifndef QT_NO_NETWORKINTERFACE
   QStringList ret;
+  ret.push_back("0.0.0.0");
   for(const QNetworkInterface& iface : QNetworkInterface::allInterfaces())
     for(const QNetworkAddressEntry& entry : iface.addressEntries())
       if(const auto& ip = entry.ip(); ip.protocol() == QAbstractSocket::IPv4Protocol)
         ret.push_back(ip.toString());
   return ret;
 #else
-  return {"127.0.0.1"};
+  return {"0.0.0.0", "127.0.0.1"};
 #endif
   /*
   using namespace boost::asio;
