@@ -13,7 +13,6 @@ template <typename Node_T>
 struct GfxRenderer<Node_T> final : score::gfx::OutputNodeRenderer
 {
   using texture_inputs = avnd::texture_input_introspection<Node_T>;
-  const GfxNode<Node_T>& parent;
   Node_T state;
   score::gfx::Message m_last_message{};
   ossia::small_flat_map<const score::gfx::Port*, score::gfx::TextureRenderTarget, 2>
@@ -22,12 +21,15 @@ struct GfxRenderer<Node_T> final : score::gfx::OutputNodeRenderer
   std::vector<QRhiReadbackResult> m_readbacks;
   ossia::time_value m_last_time{-1};
 
+  const GfxNode<Node_T>& node() const noexcept
+  {
+    return static_cast<const GfxNode<Node_T>&>(score::gfx::NodeRenderer::node);
+  }
   GfxRenderer(const GfxNode<Node_T>& p)
-      : score::gfx::OutputNodeRenderer{}
-      , parent{p}
+      : score::gfx::OutputNodeRenderer{p}
       , m_readbacks(texture_inputs::size)
   {
-    prepareNewState(state, parent);
+    prepareNewState(state, p);
   }
 
   score::gfx::TextureRenderTarget
@@ -42,26 +44,26 @@ struct GfxRenderer<Node_T> final : score::gfx::OutputNodeRenderer
   void createInput(
       score::gfx::RenderList& renderer, int k, const Tex& texture_spec, QSize size)
   {
-    auto port = parent.input[k];
+    auto port = this->node().input[k];
     static constexpr auto flags
         = QRhiTexture::RenderTarget | QRhiTexture::UsedAsTransferSource;
     auto texture = renderer.state.rhi->newTexture(
         gpp::qrhi::textureFormat<Tex>(), size, 1, flags);
     SCORE_ASSERT(texture->create());
-    m_rts[port]
-        = score::gfx::createRenderTarget(renderer.state, texture, renderer.samples());
+    m_rts[port] = score::gfx::createRenderTarget(
+        renderer.state, texture, renderer.samples(), renderer.requiresDepth());
   }
 
   QRhiTexture* texture(int k) const noexcept
   {
-    auto port = parent.input[k];
+    auto port = this->node().input[k];
     auto it = m_rts.find(port);
     SCORE_ASSERT(it != m_rts.end());
     SCORE_ASSERT(it->second.texture);
     return it->second.texture;
   }
 
-  void loadInputTexture(avnd::cpu_texture auto& cpu_tex, int k)
+  void loadInputTexture(QRhi& rhi, avnd::cpu_texture auto& cpu_tex, int k)
   {
     auto& buf = m_readbacks[k].data;
     if(buf.size() != 4 * cpu_tex.width * cpu_tex.height)
@@ -71,6 +73,11 @@ struct GfxRenderer<Node_T> final : score::gfx::OutputNodeRenderer
     else
     {
       cpu_tex.bytes = reinterpret_cast<unsigned char*>(buf.data());
+
+      if(rhi.isYUpInFramebuffer())
+        if(cpu_tex.width * cpu_tex.height > 0)
+          inplaceMirror(cpu_tex.bytes, cpu_tex.width, cpu_tex.height);
+
       cpu_tex.changed = true;
     }
   }
@@ -79,8 +86,8 @@ struct GfxRenderer<Node_T> final : score::gfx::OutputNodeRenderer
   {
     if constexpr(requires { state.prepare(); })
     {
-      parent.processControlIn(
-          *this, state, m_last_message, this->parent.last_message, this->parent.m_ctx);
+      this->node().processControlIn(
+          *this, state, m_last_message, this->node().last_message, this->node().m_ctx);
       state.prepare();
     }
 
@@ -107,7 +114,10 @@ struct GfxRenderer<Node_T> final : score::gfx::OutputNodeRenderer
     });
   }
 
-  void update(score::gfx::RenderList& renderer, QRhiResourceUpdateBatch& res) override {
+  void update(
+      score::gfx::RenderList& renderer, QRhiResourceUpdateBatch& res,
+      score::gfx::Edge* edge) override
+  {
     bool updated = false;
     /*
     int k = 0;
@@ -157,8 +167,9 @@ struct GfxRenderer<Node_T> final : score::gfx::OutputNodeRenderer
       score::gfx::RenderList& renderer, const score::gfx::Port& p,
       QRhiResourceUpdateBatch*& res) override
   {
+    auto& parent = this->node();
     res = renderer.state.rhi->nextResourceUpdateBatch();
-    const auto& inputs = this->parent.input;
+    const auto& inputs = parent.input;
     auto index_of_port = ossia::find(inputs, &p) - inputs.begin();
     SCORE_ASSERT(index_of_port == 0);
     {
@@ -173,8 +184,12 @@ struct GfxRenderer<Node_T> final : score::gfx::OutputNodeRenderer
       score::gfx::RenderList& renderer, QRhiCommandBuffer& commands,
       QRhiResourceUpdateBatch*& res, score::gfx::Edge& edge) override
   {
+    auto& parent = this->node();
     auto& rhi = *renderer.state.rhi;
 
+    // Insert a synchronisation point to allow readbacks to complete
+    rhi.finish();
+
     // If we are paused, we don't run the processor implementation.
     if(parent.last_message.token.date == m_last_time)
     {
@@ -184,22 +199,19 @@ struct GfxRenderer<Node_T> final : score::gfx::OutputNodeRenderer
 
     // Fetch input textures (if any)
     {
-      // Insert a synchronisation point to allow readbacks to complete
-      rhi.finish();
-
       // Copy the readback output inside the structure
       // TODO it would be much better to do this inside the readback's
       // "completed" callback.
       int k = 0;
       avnd::cpu_texture_input_introspection<Node_T>::for_all(
           avnd::get_inputs<Node_T>(state), [&](auto& t) {
-            loadInputTexture(t.texture, k);
-            k++;
-          });
+        loadInputTexture(rhi, t.texture, k);
+        k++;
+      });
     }
 
     parent.processControlIn(
-        *this, state, m_last_message, this->parent.last_message, this->parent.m_ctx);
+        *this, state, m_last_message, parent.last_message, parent.m_ctx);
 
     // Run the processor
     state();
