@@ -17,6 +17,9 @@
 
 #include <ossia/dataflow/execution_state.hpp>
 #include <ossia/dataflow/nodes/faust/faust_node.hpp>
+#include <ossia/detail/disable_fpe.hpp>
+
+#include <boost/predef.h>
 
 #include <QDialog>
 #include <QDialogButtonBox>
@@ -29,7 +32,9 @@
 #include <Faust/Commands.hpp>
 #include <Faust/Descriptor.hpp>
 #include <Faust/Utils.hpp>
-
+#if BOOST_ARCH_X86
+#include <xmmintrin.h>
+#endif
 #include <wobjectimpl.h>
 
 #if __has_include(<sndfile.h>)
@@ -70,6 +75,8 @@ EffectProcessFactory_T<Faust::FaustEffectModel>::descriptor(QString txt) const n
     d.author = desc.author;
   else if(!desc.copyright.isEmpty())
     d.author = desc.copyright;
+  else
+    d.author = "Faust DSP author";
 
   if(!desc.description.isEmpty())
     d.description = desc.description;
@@ -244,6 +251,12 @@ Process::ScriptChangeResult FaustEffectModel::reload()
   score::delete_later<Process::Inlets>& inlets_to_clear = res.inlets;
   score::delete_later<Process::Outlets>& outlets_to_clear = res.outlets;
 
+  // Needed because Faust crashes without FPE
+  struct on_finished
+  {
+    ~on_finished() { ossia::disable_fpe(); }
+  } fpe_guard;
+
   auto fx_text = m_script.toUtf8();
   if(fx_text.isEmpty())
   {
@@ -301,6 +314,11 @@ Process::ScriptChangeResult FaustEffectModel::reload()
   err.resize(4097);
   llvm_dsp_factory* fac{};
 
+#if BOOST_ARCH_X86
+  // https://github.com/grame-cncm/faust/issues/1117
+  _mm_setcsr(_MM_MASK_MASK | _MM_FLUSH_ZERO_OFF);
+#endif
+
   fac = createDSPFactoryFromString(
       "score", str, argv.size(), argv.data(), triple, err, -1);
 
