@@ -5,10 +5,10 @@
 #include <ossia/detail/flat_set.hpp>
 
 #include <boost/algorithm/string.hpp>
+#include <boost/regex.hpp>
 
 #include <array>
 #include <iostream>
-#include <regex>
 #include <sstream>
 #include <unordered_map>
 #include <vector>
@@ -31,7 +31,6 @@ static constexpr struct glsl45_t
   static constexpr auto vertexPrelude = R"_(
 layout(location = 0) in vec2 position;
 layout(location = 1) in vec2 texcoord;
-//layout(location = 0) out vec2 isf_TexCoord;
 layout(location = 0) out vec2 isf_FragNormCoord;
 
 )_";
@@ -39,8 +38,10 @@ layout(location = 0) out vec2 isf_FragNormCoord;
 void isf_vertShaderInit()
 {
   gl_Position = clipSpaceCorrMatrix * vec4( position, 0.0, 1.0 );
-//  isf_TexCoord = texcoord;
   isf_FragNormCoord = vec2((gl_Position.x+1.0)/2.0, (gl_Position.y+1.0)/2.0);
+#if defined(QSHADER_SPIRV) || defined(QSHADER_HLSL) || defined(QSHADER_MSL)
+  gl_Position.y = - gl_Position.y;
+#endif
 }
 )_";
 
@@ -52,7 +53,6 @@ void main()
 )_";
 
   static constexpr auto fragmentPrelude = R"_(
-//layout(location = 0) in vec2 isf_TexCoord;
 layout(location = 0) in vec2 isf_FragNormCoord;
 layout(location = 0) out vec4 isf_FragColor;
 )_";
@@ -60,103 +60,64 @@ layout(location = 0) out vec4 isf_FragColor;
   static constexpr auto defaultUniforms = R"_(
 // Shared uniform buffer for the whole render window
 layout(std140, binding = 0) uniform renderer_t {
-  mat4 clipSpaceCorrMatrix;
+  mat4 clipSpaceCorrMatrix_;
 
-  vec2 RENDERSIZE;
+  vec2 RENDERSIZE_;
 } isf_renderer_uniforms;
 
 // This dance is needed because otherwise
 // spirv-cross may generate different struct names in the vertex & fragment, causing crashes..
 // but we have to keep compat with ISF
-mat4 clipSpaceCorrMatrix = isf_renderer_uniforms.clipSpaceCorrMatrix;
-vec2 RENDERSIZE = isf_renderer_uniforms.RENDERSIZE;
+#define clipSpaceCorrMatrix isf_renderer_uniforms.clipSpaceCorrMatrix_
 
 // Time-dependent uniforms, only relevant during execution
 layout(std140, binding = 1) uniform process_t {
-  float TIME;
-  float TIMEDELTA;
-  float PROGRESS;
+  float TIME_;
+  float TIMEDELTA_;
+  float PROGRESS_;
 
-  int PASSINDEX;
-  int FRAMEINDEX;
+  int PASSINDEX_;
+  int FRAMEINDEX_;
 
-  vec4 DATE;
+  vec2 RENDERSIZE_;
+  vec4 DATE_;
+  vec4 MOUSE_;
+  vec4 CHANNEL_TIME_;
+  float SAMPLERATE_;
 } isf_process_uniforms;
  
-float TIME = isf_process_uniforms.TIME;
-float TIMEDELTA = isf_process_uniforms.TIMEDELTA;
-float PROGRESS = isf_process_uniforms.PROGRESS;
-int PASSINDEX = isf_process_uniforms.PASSINDEX;
-int FRAMEINDEX = isf_process_uniforms.FRAMEINDEX;
-vec4 DATE = isf_process_uniforms.DATE;
+#define TIME isf_process_uniforms.TIME_
+#define TIMEDELTA isf_process_uniforms.TIMEDELTA_
+#define PROGRESS isf_process_uniforms.PROGRESS_
+#define PASSINDEX isf_process_uniforms.PASSINDEX_
+#define FRAMEINDEX isf_process_uniforms.FRAMEINDEX_
+#define RENDERSIZE isf_process_uniforms.RENDERSIZE_
+#define MOUSE isf_process_uniforms.MOUSE_
+#define DATE isf_process_uniforms.DATE_
 )_";
 
-
   static constexpr auto defaultFunctions =
       R"_(
 #define TEX_DIMENSIONS(tex) isf_material_uniforms._ ## tex ## _imgRect.zw
-//#define IMG_THIS_PIXEL(tex) texture(tex, isf_FragNormCoord * TEX_DIMENSIONS(tex))
-//#define IMG_THIS_NORM_PIXEL(tex) texture(tex, isf_FragNormCoord * TEX_DIMENSIONS(tex))
-//#define IMG_PIXEL(tex, coord) texture(tex, coord * TEX_DIMENSIONS(tex) / RENDERSIZE)
-//#define IMG_NORM_PIXEL(tex, coord) texture(tex, coord * TEX_DIMENSIONS(tex))
-
-//#define IMG_THIS_PIXEL(tex) texture(tex, isf_FragNormCoord * TEX_DIMENSIONS(tex) / RENDERSIZE)
-//#define IMG_THIS_NORM_PIXEL(tex) texture(tex, isf_FragNormCoord * TEX_DIMENSIONS(tex) / RENDERSIZE)
-//#define IMG_PIXEL(tex, coord) texture(tex, coord * TEX_DIMENSIONS(tex) / RENDERSIZE)
-//#define IMG_NORM_PIXEL(tex, coord) texture(tex, coord * TEX_DIMENSIONS(tex) / RENDERSIZE)
+#define IMG_SIZE(tex) isf_material_uniforms._ ## tex ## _imgRect.zw
 
+#if defined(QSHADER_SPIRV)
+#define isf_FragCoord vec2(gl_FragCoord.x, RENDERSIZE.y - gl_FragCoord.y)
+#define ISF_FIXUP_TEXCOORD(coord) vec2((coord).x, 1. - (coord).y)
+#define IMG_THIS_PIXEL(tex) texture(tex, ISF_FIXUP_TEXCOORD(isf_FragNormCoord))
+#define IMG_THIS_NORM_PIXEL(tex) texture(tex, ISF_FIXUP_TEXCOORD(isf_FragNormCoord))
+#define IMG_PIXEL(tex, coord) texture(tex, ISF_FIXUP_TEXCOORD(coord / RENDERSIZE))
+#define IMG_NORM_PIXEL(tex, coord) texture(tex, ISF_FIXUP_TEXCOORD(coord))
+#else
+#define isf_FragCoord gl_FragCoord
 #define IMG_THIS_PIXEL(tex) texture(tex, isf_FragNormCoord)
 #define IMG_THIS_NORM_PIXEL(tex) texture(tex, isf_FragNormCoord)
-#define IMG_PIXEL(tex, coord) texture(tex, coord / RENDERSIZE)
+#define IMG_PIXEL(tex, coord) texture(tex, (coord) / RENDERSIZE)
 #define IMG_NORM_PIXEL(tex, coord) texture(tex, coord)
+#endif
 )_";
 
 } GLSL45;
-
-static constexpr struct glsl3_t
-{
-  static constexpr auto defaultVertexShader = R"_(#version 330
-in vec2 position;
-uniform vec2 RENDERSIZE;
-out vec2 isf_FragNormCoord;
-
-void main(void) {
-  gl_Position = vec4( position, 0.0, 1.0 );
-  isf_FragNormCoord = vec2((gl_Position.x+1.0)/2.0, (gl_Position.y+1.0)/2.0);
-}
-)_";
-
-  static constexpr auto vertexPrelude =
-      R"_(#version 330
-in vec2 position;
-uniform vec2 RENDERSIZE;
-out vec2 isf_FragNormCoord;
-
-void isf_vertShaderInit(void) {
-  gl_Position = vec4( position, 0.0, 1.0 );
-  isf_FragNormCoord = vec2((gl_Position.x+1.0)/2.0, (gl_Position.y+1.0)/2.0);
-}
-)_";
-
-  static constexpr auto fragmentPrelude = R"_(#version 330
-
-in vec2 isf_FragNormCoord;
-out vec4 isf_FragColor;
-)_";
-
-  static constexpr auto defaultUniforms = R"_(
-uniform vec2 RENDERSIZE;
-
-uniform float TIME;
-uniform float TIMEDELTA;
-uniform float PROGRESS;
-uniform int FRAMEINDEX;
-uniform vec4 DATE;
-
-uniform int PASSINDEX;
-)_";
-
-} GLSL3;
 }
 
 parser::parser(std::string geom)
@@ -424,6 +385,10 @@ static void parse_input(Input_T& inp, const sajson::value& v)
       inp.def = parse_input_impl(val, typename Input_T::value_type{});
     }
   }
+
+  // Some ISF shaders have e.g. "MIN": 0, "MAX": -5 to show them reversed in the ISF editor gui...
+  if(inp.min > inp.max)
+    std::swap(inp.min, inp.max);
 }
 
 template <
@@ -555,6 +520,14 @@ static const std::unordered_map<std::string, root_fun>& root_parse{[] {
                 = obj.get_object_value(float_k).get_type() == sajson::TYPE_TRUE;
           }
 
+          if(auto float_k = obj.find_object_key_insensitive(sajson::literal("FILTER"));
+             float_k != obj.get_length())
+          {
+            const auto& val = obj.get_object_value(float_k);
+            p.nearest_filter = val.get_type() == sajson::TYPE_STRING
+                               && val.as_string() == std::string_view("NEAREST");
+          }
+
           if(auto width_k = obj.find_object_key_insensitive(sajson::literal("WIDTH"));
              width_k != obj.get_length())
           {
@@ -637,18 +610,15 @@ struct create_val_visitor_450
   return_type operator()(const audioFFT_input&) { return {"uniform sampler2D", true}; }
 };
 
-std::string parser::parse_isf_header(std::string_view source)
+std::pair<int, descriptor> parser::parse_isf_header(std::string_view source)
 {
   using namespace std::literals;
-
   auto start = source.find("/*");
   if(start == std::string::npos)
     throw invalid_file{"Missing start comment"};
   auto end = source.find("*/", start);
   if(end == std::string::npos)
     throw invalid_file{"Unfinished comment"};
-  std::string fragWithoutISF = std::string(source);
-  fragWithoutISF.erase(0, end + 2);
 
   // First comes the json part
   auto doc = sajson::parse(
@@ -681,9 +651,7 @@ std::string parser::parse_isf_header(std::string_view source)
       (it->second)(d, root.get_object_value(i));
     }
   }
-  m_desc = d;
-
-  return fragWithoutISF;
+  return {end, std::move(d)};
 }
 
 static ossia::flat_set<std::string>
@@ -695,6 +663,8 @@ extract_glsl_function_definitions(std::string_view str)
 
   // :upside-down-face:
   ossia::flat_set<std::string> defs;
+  // FIXME: this is leaky due to some strdup calls.
+  // Calling glsl_parse_dealloc(&context); crashes.
   bool error = glsl_parse_string(&context, str.data());
   if(!error && context.root
      && context.root->code == (int)glsl_tokentype::TRANSLATION_UNIT)
@@ -742,7 +712,11 @@ void parser::parse_geometry_filter()
 {
   using namespace std::literals;
 
-  auto geomWithoutISF = parse_isf_header(m_source_geometry_filter);
+  auto [end, desc] = parse_isf_header(m_source_geometry_filter);
+  m_desc = std::move(desc);
+
+  std::string& geomWithoutISF = m_source_geometry_filter;
+  geomWithoutISF.erase(0, end + 2);
 
   // There is always one pass at least
   if(m_desc.passes.empty())
@@ -800,7 +774,13 @@ void parser::parse_isf()
 {
   using namespace std::literals;
 
-  auto fragWithoutISF = parse_isf_header(m_sourceFragment);
+  auto [end, desc] = parse_isf_header(m_sourceFragment);
+  m_desc = std::move(desc);
+
+  std::string& fragWithoutISF = m_sourceFragment;
+  fragWithoutISF.erase(0, end + 2);
+
+  boost::replace_all(fragWithoutISF, "gl_FragCoord", "isf_FragCoord");
 
   // There is always one pass at least
   if(m_desc.passes.empty())
@@ -819,37 +799,6 @@ void parser::parse_isf()
   // Create the GLSL prelude
   switch(m_version)
   {
-    case 330: {
-      // Setup vertex shader
-      if(m_sourceVertex.empty())
-      {
-        m_vertex = GLSL3.defaultVertexShader;
-      }
-      else if(m_sourceVertex.find("isf_vertShaderInit()") != std::string::npos)
-      {
-        m_vertex = GLSL3.vertexPrelude;
-        m_vertex += m_sourceVertex;
-      }
-      else
-      {
-        m_vertex = m_sourceVertex;
-      }
-
-      // Setup fragment shader
-      m_fragment = GLSL3.fragmentPrelude;
-      m_fragment += GLSL3.defaultUniforms;
-
-      for(const isf::input& val : d.inputs)
-      {
-        m_fragment += ossia::visit(create_val_visitor{}, val.data);
-        m_fragment += ' ';
-        m_fragment += val.name;
-        m_fragment += ";\n";
-      }
-
-      break;
-    }
-
     case 450: {
       // Setup vertex shader
       {
@@ -875,9 +824,9 @@ void parser::parse_isf()
       // Setup the parameters UBOs
       std::string material_ubos = GLSL45.defaultUniforms;
 
-      int binding = 3;
+      int sampler_binding = 3;
 
-      if(!d.inputs.empty() || !d.passes.empty())
+      if(!d.inputs.empty() || !d.pass_targets.empty())
       {
         std::string samplers;
         std::string globalvars;
@@ -889,7 +838,7 @@ void parser::parse_isf()
           if(isSampler)
           {
             samplers += "layout(binding = ";
-            samplers += std::to_string(binding);
+            samplers += std::to_string(sampler_binding);
             samplers += ") ";
             samplers += type;
             samplers += ' ';
@@ -899,10 +848,13 @@ void parser::parse_isf()
             auto imgRect_varname = "_" + val.name + "_imgRect";
             material_ubos += "vec4 " + imgRect_varname + ";\n";
             // See comment above regarding little dance to make spirv-cross happy
-            globalvars += "vec4 " + imgRect_varname + " = isf_material_uniforms."
-                          + imgRect_varname + ";\n";
+            globalvars += "vec4 ";
+            globalvars += imgRect_varname;
+            globalvars += " = isf_material_uniforms.";
+            globalvars += imgRect_varname;
+            globalvars += ";\n";
 
-            binding++;
+            sampler_binding++;
           }
           else
           {
@@ -924,14 +876,14 @@ void parser::parse_isf()
         for(const std::string& target : d.pass_targets)
         {
           samplers += "layout(binding = ";
-          samplers += std::to_string(binding);
+          samplers += std::to_string(sampler_binding);
           samplers += ") uniform sampler2D ";
           samplers += target;
           samplers += ";\n";
 
           material_ubos += "vec4 _" + target + "_imgRect;\n";
 
-          binding++;
+          sampler_binding++;
         }
 
         material_ubos += "} isf_material_uniforms;\n";
@@ -965,13 +917,8 @@ void parser::parse_isf()
   m_fragment += fragWithoutISF;
 
   // Replace the special ISF stuff
-  static const std::regex img_size("IMG_SIZE\\((.+?)\\)");
-  static const std::regex gl_FragColor("gl_FragColor");
-  static const std::regex vv_Frag("vv_Frag");
-
-  m_fragment = std::regex_replace(m_fragment, img_size, "_$1_imgRect.zw");
-  m_fragment = std::regex_replace(m_fragment, gl_FragColor, "isf_FragColor");
-  m_fragment = std::regex_replace(m_fragment, vv_Frag, "isf_Frag");
+  boost::replace_all(m_fragment, "gl_FragColor", "isf_FragColor");
+  boost::replace_all(m_fragment, "vv_Frag", "isf_Frag");
 }
 
 void parser::parse_shadertoy()
@@ -1002,26 +949,17 @@ void parser::parse_shadertoy()
 
   m_fragment += m_sourceFragment;
 
-  m_fragment
-      = std::regex_replace(m_fragment, std::regex("iGlobalTime"), "TIME"); // float
-  m_fragment
-      = std::regex_replace(m_fragment, std::regex("iGlobalDelta"), "TIMEDELTA"); // float
-  m_fragment = std::regex_replace(
-      m_fragment, std::regex("iGlobalFrame"), "FRAMEINDEX"); // float -> int
-  m_fragment = std::regex_replace(m_fragment, std::regex("iDate"), "DATE"); // vec4
-  m_fragment
-      = std::regex_replace(m_fragment, std::regex("iSampleRate"), "SAMPLERATE"); // float
-  m_fragment = std::regex_replace(
-      m_fragment, std::regex("iResolution"), "RENDERSIZE"); // vec3 -> vec2
+  boost::replace_all(m_fragment, "iGlobalTime", "TIME");        // float
+  boost::replace_all(m_fragment, "iGlobalDelta", "TIMEDELTA");  // float
+  boost::replace_all(m_fragment, "iGlobalFrame", "FRAMEINDEX"); // float -> int
+  boost::replace_all(m_fragment, "iDate", "DATE");              // vec4
+  boost::replace_all(m_fragment, "iSampleRate", "SAMPLERATE");  // float
+  boost::replace_all(m_fragment, "iResolution", "RENDERSIZE");  // vec3 -> vec2
 
-  m_fragment = std::regex_replace(m_fragment, std::regex("iMouse"), "MOUSE"); // vec4
-  m_fragment = std::regex_replace(
-      m_fragment, std::regex("iChannelTime"), "CHANNELTIME"); // float[4]
-  m_fragment = std::regex_replace(
-      m_fragment, std::regex("iChannelResolution"),
-      "CHANNELRESOLUTION"); // vec3[4]
-  m_fragment = std::regex_replace(
-      m_fragment, std::regex("iChannel0"), "CHANNEL"); // sampler2D / 3D
+  boost::replace_all(m_fragment, "iMouse", "MOUSE");                         // vec4
+  boost::replace_all(m_fragment, "iChannelTime", "CHANNELTIME");             // float[4]
+  boost::replace_all(m_fragment, "iChannelResolution", "CHANNELRESOLUTION"); // vec3[4]
+  boost::replace_all(m_fragment, "iChannel0", "CHANNEL"); // sampler2D / 3D
 
   m_fragment +=
       R"_(
@@ -1052,9 +990,9 @@ void parser::parse_glsl_sandbox()
 
   m_fragment += m_sourceFragment;
 
-  m_fragment = std::regex_replace(m_fragment, std::regex("time"), "TIME");
-  m_fragment = std::regex_replace(m_fragment, std::regex("resolution"), "RENDERSIZE");
-  m_fragment = std::regex_replace(m_fragment, std::regex("mouse"), "MOUSE");
+  boost::replace_all(m_fragment, "time", "TIME");
+  boost::replace_all(m_fragment, "resolution", "RENDERSIZE");
+  boost::replace_all(m_fragment, "mouse", "MOUSE");
 
   m_vertex =
       R"_(
