@@ -10,6 +10,7 @@
 
 #include <score/application/GUIApplicationContext.hpp>
 #include <score/tools/DeleteAll.hpp>
+#include <score/tools/File.hpp>
 
 #include <QFileInfo>
 
@@ -73,9 +74,7 @@ Model::~Model() { }
 
 bool Model::validate(const ShaderSource& txt) const noexcept
 {
-  score::gfx::GraphicsApi api = score::gfx::GraphicsApi::Vulkan;
-  QShaderVersion version = QShaderVersion(100);
-  const auto& [_, error] = ProgramCache::instance().get(api, version, txt);
+  const auto& [_, error] = ProgramCache::instance().get(txt);
   if(!error.isEmpty())
   {
     this->errorMessage(error);
@@ -106,13 +105,9 @@ void Model::setFragment(QString f)
 
 Process::ScriptChangeResult Model::setProgram(const ShaderSource& f)
 {
-  score::gfx::GraphicsApi api = score::gfx::GraphicsApi::Vulkan;
-  QShaderVersion version = QShaderVersion(100);
-
   setVertex(f.vertex);
   setFragment(f.fragment);
-  if(const auto& [processed, error] = ProgramCache::instance().get(api, version, f);
-     bool(processed))
+  if(const auto& [processed, error] = ProgramCache::instance().get(f); bool(processed))
   {
     ossia::flat_map<QString, ossia::value> previous_values;
     for(auto inl : m_inlets)
@@ -364,6 +359,31 @@ void Model::setupIsf(
 
   // m_inlets.push_back(new GeometryInlet{Id<Process::Port>(i), this});
 }
+
+Process::Descriptor ProcessFactory::descriptor(QString path) const noexcept
+{
+  auto base = Metadata<Process::Descriptor_k, Filter::Model>::get();
+
+  QFile f{path};
+  if(!f.open(QIODevice::ReadOnly))
+    return base;
+
+  try
+  {
+    auto [_, desc] = isf::parser::parse_isf_header(score::readFileAsString(f));
+    if(!desc.credits.empty())
+      base.author = QString::fromStdString(desc.credits);
+    if(!desc.description.empty())
+      base.description = QString::fromStdString(desc.credits);
+    for(auto& cat : desc.categories)
+      base.tags.push_back(QString::fromStdString(cat));
+  }
+  catch(...)
+  {
+  }
+
+  return base;
+}
 }
 
 template <>
