@@ -28,6 +28,7 @@ static int imageIndex(int idx, int size)
     return 0;
   }
 }
+
 static const constexpr auto images_single_vertex_shader = R"_(#version 450
 layout(location = 0) in vec2 position;
 layout(location = 1) in vec2 texcoord;
@@ -69,6 +70,9 @@ void main()
 
   v_texcoord = texcoord;
   gl_Position = renderer.clipSpaceCorrMatrix * vec4(pos, 0.0, 1.);
+#if defined(QSHADER_HLSL) || defined(QSHADER_MSL)
+  gl_Position.y = - gl_Position.y;
+#endif
 }
 )_";
 
@@ -103,6 +107,29 @@ void main ()
 }
 )_";
 
+static const constexpr auto images_tiled_vertex_shader = R"_(#version 450
+layout(location = 0) in vec2 position;
+layout(location = 1) in vec2 texcoord;
+
+layout(location = 0) out vec2 v_texcoord;
+
+layout(std140, binding = 0) uniform renderer_t {
+  mat4 clipSpaceCorrMatrix;
+  vec2 renderSize;
+} renderer;
+
+out gl_PerVertex { vec4 gl_Position; };
+
+void main()
+{
+  v_texcoord = texcoord;
+  gl_Position = renderer.clipSpaceCorrMatrix * vec4(position.xy, 0.0, 1.);
+#if defined(QSHADER_HLSL) || defined(QSHADER_MSL)
+  gl_Position.y = - gl_Position.y;
+#endif
+}
+)_";
+
 static const constexpr auto images_tiled_fragment_shader = R"_(#version 450
 layout(std140, binding = 0) uniform renderer_t {
   mat4 clipSpaceCorrMatrix;
@@ -137,6 +164,7 @@ void main ()
   // Aspect ratio
   // Our mesh is: -1, -1;  1, -1;  -1, 1;  1, 1;
 
+  // FIXME incorrect
   pos.x /= viewportAspect;
   pos.y /= imageAspect;
 
@@ -349,7 +377,7 @@ private:
           rs, images_single_vertex_shader, images_single_fragment_shader);
     else
       std::tie(v, f) = score::gfx::makeShaders(
-          rs, TexturedTriangle{}.defaultVertexShader(), images_tiled_fragment_shader);
+          rs, images_tiled_vertex_shader, images_tiled_fragment_shader);
 
     // Create the sampler in which we are going to put the texture
     {
@@ -364,7 +392,7 @@ private:
     // Initialize the passes for the "tiled" case
     {
       auto [v, f] = score::gfx::makeShaders(
-          rs, TexturedTriangle{}.defaultVertexShader(), images_tiled_fragment_shader);
+          rs, images_tiled_vertex_shader, images_tiled_fragment_shader);
       for(Edge* edge : this->node.output[0]->edges)
       {
         auto rt = renderer.renderTargetForOutput(*edge);
@@ -379,7 +407,7 @@ private:
     }
   }
 
-  void update(RenderList& renderer, QRhiResourceUpdateBatch& res) override
+  void update(RenderList& renderer, QRhiResourceUpdateBatch& res, Edge* edge) override
   {
     auto& n = static_cast<const ImagesNode&>(this->node);
 
@@ -461,7 +489,7 @@ private:
       m_prev_ubo.currentImageIndex = n.ubo.currentImageIndex;
     }
 
-    GenericNodeRenderer::update(renderer, res);
+    GenericNodeRenderer::update(renderer, res, edge);
   }
 
   void runRenderPass(RenderList& renderer, QRhiCommandBuffer& cb, Edge& edge) override
@@ -551,7 +579,7 @@ private:
           rs, images_single_vertex_shader, images_single_fragment_shader);
     else
       std::tie(v, f) = score::gfx::makeShaders(
-          rs, TexturedTriangle{}.defaultVertexShader(), images_tiled_fragment_shader);
+          rs, images_tiled_vertex_shader, images_tiled_fragment_shader);
 
     // Create the sampler in which we are going to put the texture
     {
@@ -569,7 +597,7 @@ private:
     // Initialize the passes for the "tiled" case
     {
       auto [v, f] = score::gfx::makeShaders(
-          rs, TexturedTriangle{}.defaultVertexShader(), images_tiled_fragment_shader);
+          rs, images_tiled_vertex_shader, images_tiled_fragment_shader);
       for(Edge* edge : this->node.output[0]->edges)
       {
         auto rt = renderer.renderTargetForOutput(*edge);
@@ -584,7 +612,7 @@ private:
     }
   }
 
-  void update(RenderList& renderer, QRhiResourceUpdateBatch& res) override
+  void update(RenderList& renderer, QRhiResourceUpdateBatch& res, Edge* edge) override
   {
     auto& n = static_cast<const ImagesNode&>(this->node);
 
@@ -648,7 +676,7 @@ private:
       }
     }
 
-    GenericNodeRenderer::update(renderer, res);
+    GenericNodeRenderer::update(renderer, res, edge);
   }
 
   void runRenderPass(RenderList& renderer, QRhiCommandBuffer& cb, Edge& edge) override
@@ -708,6 +736,9 @@ void main()
 {
   v_texcoord = vec2(texcoord.x, 1. - texcoord.y);
   gl_Position = renderer.clipSpaceCorrMatrix * vec4(position.xy, 0.0, 1.);
+#if defined(QSHADER_HLSL) || defined(QSHADER_MSL)
+  gl_Position.y = - gl_Position.y;
+#endif
 }
 )_";
 
@@ -782,9 +813,10 @@ private:
     defaultPassesInit(renderer, mesh);
   }
 
-  void update(RenderList& renderer, QRhiResourceUpdateBatch& res) override
+  void update(RenderList& renderer, QRhiResourceUpdateBatch& res, score::gfx::Edge* edge)
+      override
   {
-    GenericNodeRenderer::update(renderer, res);
+    GenericNodeRenderer::update(renderer, res, edge);
 
     auto& n = static_cast<const FullScreenImageNode&>(this->node);
     // If images haven't been uploaded yet, upload them.
