@@ -10,8 +10,10 @@ namespace score::gfx
 class SCORE_PLUGIN_GFX_EXPORT NodeRenderer
 {
 public:
-  int32_t id{-1};
-  explicit NodeRenderer() noexcept;
+  explicit NodeRenderer(const Node& node)
+      : node{node}
+  {
+  }
   virtual ~NodeRenderer();
 
   virtual TextureRenderTarget renderTargetForInput(const Port& input) = 0;
@@ -22,7 +24,8 @@ public:
   inputAboutToFinish(RenderList& renderer, const Port& p, QRhiResourceUpdateBatch*&);
 
   virtual void init(RenderList& renderer, QRhiResourceUpdateBatch& res) = 0;
-  virtual void update(RenderList& renderer, QRhiResourceUpdateBatch& res) = 0;
+  virtual void update(RenderList& renderer, QRhiResourceUpdateBatch& res, Edge* edge)
+      = 0;
 
   virtual void runInitialPasses(
       RenderList&, QRhiCommandBuffer& commands, QRhiResourceUpdateBatch*& res,
@@ -31,6 +34,26 @@ public:
   virtual void runRenderPass(RenderList&, QRhiCommandBuffer& commands, Edge& edge);
 
   virtual void release(RenderList&) = 0;
+
+  void checkForChanges()
+  {
+    materialChanged = node.hasMaterialChanged(materialChangedIndex);
+    geometryChanged = node.hasGeometryChanged(geometryChangedIndex);
+    renderTargetSpecsChanged
+        = node.hasRenderTargetChanged(renderTargetSpecsChangedIndex);
+  }
+
+  const Node& node;
+
+  int32_t id{-1};
+  bool materialChanged{false};
+  bool geometryChanged{false};
+  bool renderTargetSpecsChanged{false};
+
+private:
+  int64_t materialChangedIndex{-1};
+  int64_t geometryChangedIndex{-1};
+  int64_t renderTargetSpecsChangedIndex{-1};
 };
 
 using PassMap = ossia::small_vector<std::pair<Edge*, Pipeline>, 2>;
@@ -61,15 +84,13 @@ class SCORE_PLUGIN_GFX_EXPORT GenericNodeRenderer : public score::gfx::NodeRende
 {
 public:
   GenericNodeRenderer(const NodeModel& node) noexcept
-      : NodeRenderer{}
-      , node{node}
+      : NodeRenderer{node}
   {
   }
 
   TextureRenderTarget renderTargetForInput(const Port& p) override;
   virtual ~GenericNodeRenderer() { }
 
-  const NodeModel& node;
   std::vector<Sampler> m_samplers;
 
   QShader m_vertexS;
@@ -83,8 +104,6 @@ public:
   QRhiBuffer* m_processUBO{};
 
   DefaultShaderMaterial m_material;
-  int64_t materialChangedIndex{-1};
-  int64_t geometryChangedIndex{-1};
 
   const score::gfx::Mesh* m_mesh{};
 
@@ -101,7 +120,7 @@ public:
 
   void defaultUBOUpdate(RenderList& renderer, QRhiResourceUpdateBatch& res);
   void defaultMeshUpdate(RenderList& renderer, QRhiResourceUpdateBatch& res);
-  void update(RenderList& renderer, QRhiResourceUpdateBatch& res) override;
+  void update(RenderList& renderer, QRhiResourceUpdateBatch& res, Edge* edge) override;
 
   void defaultRelease(RenderList&);
   void release(RenderList&) override;
