@@ -31,9 +31,9 @@ PassOutput RenderedISFNode::initPassSampler(
   QRhi& rhi = *renderer.state.rhi;
   // In all the other cases we create a custom render target
   const auto fmt = (pass.float_storage) ? QRhiTexture::RGBA32F : QRhiTexture::RGBA8;
+  const auto filter = (pass.nearest_filter) ? QRhiSampler::Nearest : QRhiSampler::Linear;
   auto sampler = rhi.newSampler(
-      QRhiSampler::Linear, QRhiSampler::Linear, QRhiSampler::None, QRhiSampler::Mirror,
-      QRhiSampler::Mirror);
+      filter, filter, QRhiSampler::None, QRhiSampler::Mirror, QRhiSampler::Mirror);
   sampler->setName("ISFNode::initPassSamplers::sampler");
   sampler->create();
 
@@ -99,7 +99,7 @@ std::vector<Sampler> RenderedISFNode::allSamplers(
 }
 
 static std::pair<std::vector<Sampler>, int> initInputSamplers(
-    RenderList& renderer, const std::vector<Port*>& ports,
+    const ProcessNode& node, RenderList& renderer, const std::vector<Port*>& ports,
     ossia::small_flat_map<const Port*, TextureRenderTarget, 2>& m_rts,
     char* materialData)
 {
@@ -107,6 +107,7 @@ static std::pair<std::vector<Sampler>, int> initInputSamplers(
   QRhi& rhi = *renderer.state.rhi;
   int cur_pos = 0;
 
+  int cur_port = 0;
   for(Port* in : ports)
   {
     switch(in->type)
@@ -137,22 +138,23 @@ static std::pair<std::vector<Sampler>, int> initInputSamplers(
         cur_pos += 16;
         break;
       case Types::Image: {
+        auto spec = node.resolveRenderTargetSpecs(cur_port, renderer);
         auto sampler = rhi.newSampler(
-            QRhiSampler::Linear, QRhiSampler::Linear, QRhiSampler::None,
-            QRhiSampler::ClampToEdge, QRhiSampler::ClampToEdge);
+            spec.mag_filter, spec.min_filter, spec.mipmap_mode, spec.address_u,
+            spec.address_v, spec.address_w);
         sampler->setName("ISFNode::initInputSamplers::sampler");
         SCORE_ASSERT(sampler->create());
 
         auto rt = score::gfx::createRenderTarget(
-            renderer.state, QRhiTexture::RGBA8, renderer.state.renderSize,
-            renderer.samples());
+            renderer.state, spec.format, spec.size, renderer.samples(),
+            renderer.requiresDepth());
         auto texture = rt.texture;
         samplers.push_back({sampler, texture});
 
         m_rts[in] = std::move(rt);
 
         // Allocate some space for the vec4 _imgRect in the uniform
-        storeTextureRectUniform(materialData, cur_pos, renderer.state.renderSize);
+        storeTextureRectUniform(materialData, cur_pos, spec.size);
         break;
       }
 
@@ -162,6 +164,7 @@ static std::pair<std::vector<Sampler>, int> initInputSamplers(
       default:
         break;
     }
+    cur_port++;
   }
   return {samplers, cur_pos};
 }
@@ -186,7 +189,7 @@ initAudioTextures(RenderList& renderer, std::list<AudioTexture>& textures)
 }
 
 RenderedISFNode::RenderedISFNode(const ISFNode& node) noexcept
-    : score::gfx::NodeRenderer{}
+    : score::gfx::NodeRenderer{node}
     , n{const_cast<ISFNode&>(node)}
 {
 }
@@ -257,6 +260,8 @@ void main ()
     SCORE_ASSERT(!m_passSamplers.empty());
     auto last_sampler = ossia::get_if<PersistSampler>(&m_passSamplers.back());
     SCORE_ASSERT(last_sampler);
+    SCORE_ASSERT(last_sampler->textures[0]);
+    SCORE_ASSERT(last_sampler->textures[1]);
 
     auto pip = score::gfx::buildPipeline(
         renderer, renderer.defaultTriangle(), vertexS, fragmentS, renderTarget, nullptr,
@@ -284,12 +289,13 @@ std::pair<Pass, Pass> RenderedISFNode::createPass(
   QRhiBuffer* pubo{};
   pubo = rhi.newBuffer(
       QRhiBuffer::Dynamic, QRhiBuffer::UniformBuffer, sizeof(ProcessUBO));
-  pubo->setName("ISFNode::createPass::pubo");
+  pubo->setName("RenderedISFNode::createPass::pubo");
   pubo->create();
 
   // Create the main pass
   {
     // Render target for the pass
+    bool createdRt{};
     TextureRenderTarget renderTarget;
     if(auto rt = ossia::get_if<TextureRenderTarget>(&target))
     {
@@ -300,18 +306,34 @@ std::pair<Pass, Pass> RenderedISFNode::createPass(
     {
       // Intermediary pass
       renderTarget = score::gfx::createRenderTarget(
-          renderer.state, psampler->textures[0], renderer.samples());
+          renderer.state, psampler->textures[0], renderer.samples(), false);
       m_innerPassTargets.push_back(renderTarget);
-      renderTarget.texture->setName("ISFNode::createPass::renderTarget.texture");
+      renderTarget.texture->setName("RenderedISFNode::createPass::renderTarget.texture");
       renderTarget.renderTarget->setName(
-          "ISFNode::createPass::renderTarget.renderTarget");
+          "RenderedISFNode::createPass::renderTarget.renderTarget");
+      createdRt = true;
     }
 
-    auto [v, s] = score::gfx::makeShaders(renderer.state, n.m_vertexS, n.m_fragmentS);
-    auto pip = score::gfx::buildPipeline(
-        renderer, renderer.defaultTriangle(), v, s, renderTarget, pubo, m_materialUBO,
-        allSamplers(passSamplers, 1));
-    ret.first = Pass{renderTarget, pip, pubo};
+    try
+    {
+      auto [v, s] = score::gfx::makeShaders(renderer.state, n.m_vertexS, n.m_fragmentS);
+      auto pip = score::gfx::buildPipeline(
+          renderer, renderer.defaultTriangle(), v, s, renderTarget, pubo, m_materialUBO,
+          allSamplers(passSamplers, 1));
+
+      ret.first = Pass{renderTarget, pip, pubo};
+    }
+    catch(...)
+    {
+      pubo->destroy();
+      delete pubo;
+      if(createdRt)
+      {
+        renderTarget.release();
+        m_innerPassTargets.pop_back();
+      }
+      return {};
+    }
   }
 
   // If necessary create the alternative pass
@@ -339,12 +361,12 @@ std::pair<Pass, Pass> RenderedISFNode::createPass(
         ret.second.processUBO = ret.first.processUBO;
         ret.second.p = ret.first.p;
         ret.second.renderTarget = score::gfx::createRenderTarget(
-            renderer.state, psampler->textures[1], renderer.samples());
+            renderer.state, psampler->textures[1], renderer.samples(), false);
         m_innerPassTargets.push_back(ret.second.renderTarget);
         ret.second.renderTarget.texture->setName(
-            "ISFNode::createPass::ret.second.renderTarget.texture");
+            "RenderedISFNode::createPass::ret.second.renderTarget.texture");
         ret.second.renderTarget.renderTarget->setName(
-            "ISFNode::createPass::ret.second.renderTarget.renderTarget");
+            "RenderedISFNode::createPass::ret.second.renderTarget.renderTarget");
 
         // We necessarily use the main pass rendered-to samplers
         ret.second.p.srb = score::gfx::createDefaultBindings(
@@ -387,8 +409,8 @@ void RenderedISFNode::initPasses(
     }
     else
     {
-      passes.samplers.push_back(
-          initPassSampler(n, pass, renderer, cur_pos, mainTexSize, res));
+      auto sampler = initPassSampler(n, pass, renderer, cur_pos, mainTexSize, res);
+      passes.samplers.push_back(sampler);
     }
   }
 
@@ -398,10 +420,43 @@ void RenderedISFNode::initPasses(
     auto& pass = passes.samplers[i];
     const auto [p1, p2]
         = createPass(renderer, passes.samplers, pass, previousPassIsPersistent);
-    passes.passes.push_back(p1);
-    passes.altPasses.push_back(p2);
+    if(p1.p.pipeline)
+    {
+      passes.passes.push_back(p1);
+      passes.altPasses.push_back(p2);
 
-    previousPassIsPersistent = model_passes[i].persistent;
+      previousPassIsPersistent = model_passes[i].persistent;
+    }
+    else
+    {
+      int n = passes.passes.size();
+      for(int i = 0; i < n; i++)
+      {
+        auto& pass = passes.passes[i];
+        auto& altpass = passes.altPasses[i];
+
+        if(pass.p.srb != altpass.p.srb)
+        {
+          altpass.p.srb->deleteLater();
+        }
+
+        pass.p.release();
+
+        if(pass.processUBO)
+          pass.processUBO->deleteLater();
+        if(pass.p.srb != altpass.p.srb)
+        {
+          altpass.p.srb->deleteLater();
+        }
+
+        if(auto p = ossia::get_if<PersistSampler>(&passes.samplers[i]))
+          delete p->sampler;
+
+        pass.p.release();
+      }
+
+      return;
+    }
   }
 
   SCORE_ASSERT(passes.passes.size() == passes.samplers.size());
@@ -442,6 +497,7 @@ void RenderedISFNode::init(RenderList& renderer, QRhiResourceUpdateBatch& res)
   {
     m_materialUBO
         = rhi.newBuffer(QRhiBuffer::Dynamic, QRhiBuffer::UniformBuffer, m_materialSize);
+    m_materialUBO->setName("RenderedISFNode::init::m_materialUBO");
     SCORE_ASSERT(m_materialUBO->create());
   }
 
@@ -452,7 +508,7 @@ void RenderedISFNode::init(RenderList& renderer, QRhiResourceUpdateBatch& res)
   SCORE_ASSERT(m_audioSamplers.empty());
 
   auto [samplers, cur_pos]
-      = initInputSamplers(renderer, n.input, m_rts, n.m_material_data.get());
+      = initInputSamplers(this->n, renderer, n.input, m_rts, n.m_material_data.get());
   m_inputSamplers = std::move(samplers);
 
   m_audioSamplers = initAudioTextures(renderer, n.m_audio_textures);
@@ -466,12 +522,13 @@ void RenderedISFNode::init(RenderList& renderer, QRhiResourceUpdateBatch& res)
     auto rt = renderer.renderTargetForOutput(*edge);
     if(rt.renderTarget)
     {
-      initPasses(rt, renderer, *edge, cur_pos, renderer.state.renderSize, res);
+      initPasses(rt, renderer, *edge, cur_pos, renderer.renderSize(edge), res);
     }
   }
 }
 
-void RenderedISFNode::update(RenderList& renderer, QRhiResourceUpdateBatch& res)
+void RenderedISFNode::update(
+    RenderList& renderer, QRhiResourceUpdateBatch& res, Edge* edge)
 {
   SCORE_ASSERT(m_passes.size() > 0);
 
@@ -484,14 +541,17 @@ void RenderedISFNode::update(RenderList& renderer, QRhiResourceUpdateBatch& res)
   else
     n.standardUBO.passIndex = m_passes.size() - 1;
 
+  n.standardUBO.frameIndex++;
+
   // Update audio textures
+  bool audioChanged = false;
   for(auto& audio : n.m_audio_textures)
   {
     if(std::optional<Sampler> sampl
        = m_audioTex.updateAudioTexture(audio, renderer, n.m_material_data.get(), res))
     {
       // Audio texture changed, this means the material needs update
-      materialChangedIndex = -1;
+      audioChanged = true;
 
       auto& [rhiSampler, tex] = *sampl;
       for(auto& [e, p] : m_passes)
@@ -507,7 +567,7 @@ void RenderedISFNode::update(RenderList& renderer, QRhiResourceUpdateBatch& res)
   }
 
   // Update material
-  if(m_materialUBO && m_materialSize > 0 && n.hasMaterialChanged(materialChangedIndex))
+  if(m_materialUBO && m_materialSize > 0 && (materialChanged || audioChanged))
   {
     char* data = n.m_material_data.get();
     res.updateDynamicBuffer(m_materialUBO, 0, m_materialSize, data);
@@ -517,12 +577,34 @@ void RenderedISFNode::update(RenderList& renderer, QRhiResourceUpdateBatch& res)
 
   for(auto& [e, p] : m_passes)
   {
+    SCORE_ASSERT(p.samplers.size() == p.passes.size());
     for(int i = 0, N = p.passes.size(); i < N; i++)
     {
       auto& pass = p.passes[i];
+      auto& passoutput = p.samplers[i];
       if(pass.processUBO)
       {
         n.standardUBO.passIndex = i;
+        if(i < N - 1)
+        {
+          // renderSize is size of the pass output
+          auto persist = ossia::get_if<PersistSampler>(&passoutput);
+          SCORE_ASSERT(persist);
+          SCORE_ASSERT(persist->textures[0]);
+          const auto sz = persist->textures[0]->pixelSize();
+          n.standardUBO.renderSize[0] = sz.width();
+          n.standardUBO.renderSize[1] = sz.height();
+        }
+        else
+        {
+          // Last pass, it's a normal render target
+          auto rt = ossia::get_if<TextureRenderTarget>(&passoutput);
+          SCORE_ASSERT(rt);
+          SCORE_ASSERT(rt->texture);
+          const auto sz = rt->texture->pixelSize();
+          n.standardUBO.renderSize[0] = sz.width();
+          n.standardUBO.renderSize[1] = sz.height();
+        }
 
         res.updateDynamicBuffer(
             pass.processUBO, 0, sizeof(ProcessUBO), &this->n.standardUBO);
@@ -552,6 +634,7 @@ void RenderedISFNode::release(RenderList& r)
           if(tex != &r.emptyTexture())
             tex->deleteLater();
         }
+        // FIXME remove it from n.m_audio_textures?
       }
     }
 
@@ -628,14 +711,14 @@ void RenderedISFNode::runInitialPasses(
   // Even with a single output if a node renders to two "edges"..
 
   // Check if we just have one pass (thus nothing to render here).
-  SCORE_ASSERT(!this->m_passes.empty());
   if(this->m_passes[0].second.passes.size() == 1)
-  {
     return;
-  }
 
   auto it = ossia::find_if(this->m_passes, [&](auto& p) { return p.first == &edge; });
-  SCORE_ASSERT(it != this->m_passes.end());
+  // Maybe the shader could not be created
+  if(it == this->m_passes.end())
+    return;
+
   auto& [passes, altPasses, _] = it->second;
 
   // Draw the passes
@@ -685,7 +768,9 @@ void RenderedISFNode::runRenderPass(
     RenderList& renderer, QRhiCommandBuffer& cb, Edge& edge)
 {
   auto it = ossia::find_if(this->m_passes, [&](auto& p) { return p.first == &edge; });
-  SCORE_ASSERT(it != this->m_passes.end());
+  // Maybe the shader could not be created
+  if(it == this->m_passes.end())
+    return;
   auto& [passes, altPasses, _] = it->second;
 
   // Draw the last pass
@@ -828,6 +913,7 @@ std::optional<Sampler> AudioTextureUpload::updateAudioTexture(
 
       rhiTexture = rhi.newTexture(
           QRhiTexture::R32F, {pixelWidth, audio.channels}, 1, QRhiTexture::Flag{});
+      rhiTexture->setName("AudioTextureUpload::rhiTexture");
       rhiTexture->create();
       textureChanged = true;
     }
@@ -860,7 +946,7 @@ namespace score::gfx
 {
 
 SimpleRenderedISFNode::SimpleRenderedISFNode(const ISFNode& node) noexcept
-    : score::gfx::NodeRenderer{}
+    : score::gfx::NodeRenderer{node}
     , n{const_cast<ISFNode&>(node)}
 {
 }
@@ -893,14 +979,20 @@ void SimpleRenderedISFNode::initPass(
   QRhiBuffer* pubo{};
   pubo = rhi.newBuffer(
       QRhiBuffer::Dynamic, QRhiBuffer::UniformBuffer, sizeof(ProcessUBO));
-  pubo->setName("SimpleRenderedISFNode::createPass::pubo");
+  pubo->setName("SimpleRenderedISFNode::initPass::pubo");
   pubo->create();
 
   // Create the main pass
-  auto [v, s] = score::gfx::makeShaders(renderer.state, n.m_vertexS, n.m_fragmentS);
-  auto pip = score::gfx::buildPipeline(
-      renderer, *m_mesh, v, s, renderTarget, pubo, m_materialUBO, allSamplers());
-  m_passes.emplace_back(&edge, Pass{renderTarget, pip, pubo});
+  try
+  {
+    auto [v, s] = score::gfx::makeShaders(renderer.state, n.m_vertexS, n.m_fragmentS);
+    auto pip = score::gfx::buildPipeline(
+        renderer, *m_mesh, v, s, renderTarget, pubo, m_materialUBO, allSamplers());
+    m_passes.emplace_back(&edge, Pass{renderTarget, pip, pubo});
+  }
+  catch(...)
+  {
+  }
 }
 
 void SimpleRenderedISFNode::init(RenderList& renderer, QRhiResourceUpdateBatch& res)
@@ -926,6 +1018,7 @@ void SimpleRenderedISFNode::init(RenderList& renderer, QRhiResourceUpdateBatch&
   {
     m_materialUBO
         = rhi.newBuffer(QRhiBuffer::Dynamic, QRhiBuffer::UniformBuffer, m_materialSize);
+    m_materialUBO->setName("SimpleRenderedISFNode::init::m_materialUBO");
     SCORE_ASSERT(m_materialUBO->create());
   }
 
@@ -936,7 +1029,7 @@ void SimpleRenderedISFNode::init(RenderList& renderer, QRhiResourceUpdateBatch&
   SCORE_ASSERT(m_audioSamplers.empty());
 
   auto [samplers, cur_pos]
-      = initInputSamplers(renderer, n.input, m_rts, n.m_material_data.get());
+      = initInputSamplers(this->n, renderer, n.input, m_rts, n.m_material_data.get());
   m_inputSamplers = std::move(samplers);
 
   m_audioSamplers = initAudioTextures(renderer, n.m_audio_textures);
@@ -953,11 +1046,14 @@ void SimpleRenderedISFNode::init(RenderList& renderer, QRhiResourceUpdateBatch&
   }
 }
 
-void SimpleRenderedISFNode::update(RenderList& renderer, QRhiResourceUpdateBatch& res)
+void SimpleRenderedISFNode::update(
+    RenderList& renderer, QRhiResourceUpdateBatch& res, Edge* edge)
 {
-  SCORE_ASSERT(m_passes.size() > 0);
-
   n.standardUBO.passIndex = 0;
+  n.standardUBO.frameIndex++;
+  auto sz = renderer.renderSize(edge);
+  n.standardUBO.renderSize[0] = sz.width();
+  n.standardUBO.renderSize[1] = sz.height();
 
   // Update audio textures
   if(!n.m_audio_textures.empty() && !m_audioTex)
@@ -965,13 +1061,14 @@ void SimpleRenderedISFNode::update(RenderList& renderer, QRhiResourceUpdateBatch
     m_audioTex.emplace();
   }
 
+  bool audioChanged = false;
   for(auto& audio : n.m_audio_textures)
   {
     if(std::optional<Sampler> sampl
        = m_audioTex->updateAudioTexture(audio, renderer, n.m_material_data.get(), res))
     {
       // Texture changed -> material changed
-      materialChangedIndex = -1;
+      audioChanged = true;
 
       auto& [rhiSampler, tex] = *sampl;
       for(auto& [e, pass] : m_passes)
@@ -983,14 +1080,13 @@ void SimpleRenderedISFNode::update(RenderList& renderer, QRhiResourceUpdateBatch
   }
 
   // Update material
-  if(m_materialUBO && m_materialSize > 0 && n.hasMaterialChanged(materialChangedIndex))
+  if(m_materialUBO && m_materialSize > 0 && (materialChanged || audioChanged))
   {
     char* data = n.m_material_data.get();
     res.updateDynamicBuffer(m_materialUBO, 0, m_materialSize, data);
   }
 
   // Update all the process UBOs
-
   for(auto& [e, pass] : m_passes)
   {
     res.updateDynamicBuffer(
@@ -1061,7 +1157,10 @@ void SimpleRenderedISFNode::runRenderPass(
     RenderList& renderer, QRhiCommandBuffer& cb, Edge& edge)
 {
   auto it = ossia::find_if(this->m_passes, [&](auto& p) { return p.first == &edge; });
-  SCORE_ASSERT(it != this->m_passes.end());
+  // Maybe the shader could not be created
+  if(it == this->m_passes.end())
+    return;
+
   auto& pass = it->second;
 
   // Draw the last pass
@@ -1079,17 +1178,8 @@ void SimpleRenderedISFNode::runRenderPass(
     {
       cb.setGraphicsPipeline(pipeline);
       cb.setShaderResources(srb);
-
-      if(texture)
-      {
-        cb.setViewport(QRhiViewport(
-            0, 0, texture->pixelSize().width(), texture->pixelSize().height()));
-      }
-      else
-      {
-        const auto sz = renderer.state.renderSize;
-        cb.setViewport(QRhiViewport(0, 0, sz.width(), sz.height()));
-      }
+      cb.setViewport(QRhiViewport(
+          0, 0, texture->pixelSize().width(), texture->pixelSize().height()));
 
       m_mesh->draw({this->m_meshBuffer, this->m_idxBuffer}, cb);
     }
