@@ -2,11 +2,19 @@
 #include <Gfx/Settings/Model.hpp>
 
 #include <score/application/ApplicationContext.hpp>
+#include <score/gfx/Vulkan.hpp>
 
+#include <QGuiApplication>
 #include <QPlatformSurfaceEvent>
 #include <QTimer>
 #include <QtGui/private/qrhigles2_p.h>
-
+#if QT_HAS_VULKAN
+#if __has_include(<QtGui/private/qrhivulkan_p.h>)
+#include <QtGui/private/qrhivulkan_p.h>
+#else
+#undef QT_HAS_VULKAN
+#endif
+#endif
 #include <wobjectimpl.h>
 
 W_OBJECT_IMPL(score::gfx::Window)
@@ -17,37 +25,67 @@ Window::Window(GraphicsApi graphicsApi)
     : m_api{graphicsApi}
 {
   setCursor(Qt::BlankCursor);
+  QSurfaceFormat fmt = QSurfaceFormat::defaultFormat();
+
   // Tell the platform plugin what we want.
   switch(m_api)
   {
+    default:
     case OpenGL:
 #if QT_CONFIG(opengl)
-    {
       setSurfaceType(OpenGLSurface);
 #if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
-      auto fmt = QRhiGles2InitParams::adjustedFormat();
-#else
-      auto fmt = QSurfaceFormat::defaultFormat();
+      fmt = QRhiGles2InitParams::adjustedFormat();
 #endif
-      const int samples
-          = score::AppContext().settings<Gfx::Settings::Model>().getSamples();
-      fmt.setSamples(samples);
-      setFormat(fmt);
-    }
 #endif
     break;
+
+#if QT_HAS_VULKAN
     case Vulkan:
       setSurfaceType(VulkanSurface);
+      setVulkanInstance(score::gfx::staticVulkanInstance());
       break;
+#endif
+
+#if defined(_WIN32)
     case D3D11:
-      setSurfaceType(OpenGLSurface); // not a typo
+    case D3D12:
+      setSurfaceType(Direct3DSurface);
       break;
+#endif
+
+#if defined(__APPLE__)
     case Metal:
       setSurfaceType(MetalSurface);
       break;
+#endif
+  }
+
+  const auto& settings = score::AppContext().settings<Gfx::Settings::Model>();
+  fmt.setSwapInterval(settings.getVSync() ? 1 : 0);
+
+  switch(settings.getBuffers())
+  {
     default:
+    case 1:
+      fmt.setSwapBehavior(QSurfaceFormat::SwapBehavior::SingleBuffer);
+      break;
+    case 2:
+      fmt.setSwapBehavior(QSurfaceFormat::SwapBehavior::DoubleBuffer);
+      break;
+    case 3:
+      fmt.setSwapBehavior(QSurfaceFormat::SwapBehavior::TripleBuffer);
       break;
   }
+
+  const int samples = settings.resolveSamples(m_api);
+  fmt.setSamples(samples);
+
+  setFormat(fmt);
+
+  if(auto platform = qGuiApp->platformName();
+     platform.contains("eglfs") || platform.contains("vkkhr"))
+    m_embeddedFullscreen = true;
 }
 
 Window::~Window()
@@ -196,6 +234,11 @@ void Window::exposeEvent(QExposeEvent* ev)
     m_newlyExposed = true;
   }
 
+  if(isExposed())
+  {
+    m_closed = false;
+  }
+
   if(isExposed() && !surfaceSize.isEmpty())
     render();
 }
@@ -216,20 +259,38 @@ bool Window::event(QEvent* e)
     case QEvent::TabletMove: {
       auto ev = static_cast<QTabletEvent*>(e);
       this->tabletMove(ev);
+      this->interactiveEvent(e);
       break;
     }
     case QEvent::TabletPress:
     case QEvent::TabletRelease:
+      this->interactiveEvent(e);
+      break;
+
+    case QEvent::MouseButtonPress:
+    case QEvent::MouseButtonRelease:
+    case QEvent::MouseButtonDblClick:
+      this->interactiveEvent(e);
       break;
 
     case QEvent::MouseMove: {
       auto ev = static_cast<QMouseEvent*>(e);
       this->mouseMove(ev->globalPosition(), ev->scenePosition());
+      this->interactiveEvent(e);
       break;
     }
     case QEvent::KeyPress: {
       auto ev = static_cast<QKeyEvent*>(e);
       this->key(ev->key(), ev->text());
+      this->interactiveEvent(e);
+      if(ev->key() == Qt::Key_Escape)
+        if(m_embeddedFullscreen)
+          QMetaObject::invokeMethod(qGuiApp, &QCoreApplication::quit);
+
+      break;
+    }
+    case QEvent::KeyRelease: {
+      this->interactiveEvent(e);
       break;
     }
     case QEvent::PlatformSurface:
