@@ -125,7 +125,6 @@ struct SyphonNode final : score::gfx::OutputNode
         std::function<void()> onUpdate,
         std::function<void()> onResize) override
   {
-#include <Gfx/Qt5CompatPush> // clang-format: keep
     m_renderState = std::make_shared<score::gfx::RenderState>();
     m_update = onUpdate;
 
@@ -135,9 +134,7 @@ struct SyphonNode final : score::gfx::OutputNode
     params.format.setMinorVersion(2);
     params.format.setProfile(QSurfaceFormat::CompatibilityProfile);
     params.fallbackSurface = m_renderState->surface;
-#include <Gfx/Qt5CompatPop> // clang-format: keep
     m_renderState->rhi = QRhi::create(QRhi::OpenGLES2, &params, {});
-#include <Gfx/Qt5CompatPush> // clang-format: keep
     m_renderState->renderSize = QSize(m_settings.width, m_settings.height);
     m_renderState->api = score::gfx::GraphicsApi::OpenGL;
     m_renderState->version = QShaderVersion(120);
@@ -176,7 +173,7 @@ struct SyphonNode final : score::gfx::OutputNode
     {
     public:
       SyphonRenderer(const score::gfx::RenderState& state, const SyphonNode& parent)
-        : score::gfx::OutputNodeRenderer{}
+        : score::gfx::OutputNodeRenderer{parent}
       {
         m_rt.renderTarget = parent.m_renderTarget;
         m_rt.renderPass = state.renderPassDescriptor;
@@ -186,7 +183,10 @@ struct SyphonNode final : score::gfx::OutputNode
       void finishFrame(score::gfx::RenderList& renderer, QRhiCommandBuffer& cb,
                        QRhiResourceUpdateBatch*& res) override { }
       void init(score::gfx::RenderList& renderer, QRhiResourceUpdateBatch& res) override { }
-      void update(score::gfx::RenderList& renderer, QRhiResourceUpdateBatch& res) override { }
+      void update(score::gfx::RenderList &renderer,
+                  QRhiResourceUpdateBatch &res,
+                  score::gfx::Edge *edge) override
+      {}
       void release(score::gfx::RenderList&) override { }
     private:
       score::gfx::TextureRenderTarget m_rt;
@@ -210,8 +210,6 @@ private:
   bool m_created{};
 };
 
-#include <Gfx/Qt5CompatPop> // clang-format: keep
-
 SyphonDevice::~SyphonDevice() { }
 
 bool SyphonDevice::reconnect()
