@@ -31,25 +31,7 @@ namespace Gfx
 static score::gfx::ScreenNode* createScreenNode()
 {
   const auto& settings = score::AppContext().applicationSettings;
-  if(settings.autoplay || !settings.gui)
-  //if(QGuiApplication::platformName().toLower().contains("gl"))
-  {
-    return new score::gfx::ScreenNode{false, true};
-
-    /*
-    auto window = std::make_shared<Window>(defaultGraphicsAPI());
-    window->showFullScreen();
-    QCoreApplication::processEvents();
-    QCoreApplication::processEvents();
-    QCoreApplication::processEvents();
-    return new ScreenNode{window};
-    */
-  }
-  else
-
-  {
-    return new score::gfx::ScreenNode;
-  }
+  return new score::gfx::ScreenNode{false, (settings.autoplay || !settings.gui)};
 }
 
 class window_device : public ossia::net::device_base
@@ -61,14 +43,16 @@ class window_device : public ossia::net::device_base
 public:
   ~window_device()
   {
+    if(auto w = m_screen->window())
+      w->close();
+
+    m_screen->onWindowMove = [](QPointF) {};
     m_screen->onMouseMove = [](QPointF, QPointF) {};
     m_screen->onTabletMove = [](QTabletEvent*) {};
     m_screen->onKey = [](int, const QString&) {};
     m_protocol->stop();
 
-    {
-      m_root.clear_children();
-    }
+    m_root.clear_children();
 
     m_protocol.reset();
   }
@@ -79,11 +63,12 @@ public:
       , m_root{*this, *static_cast<gfx_protocol_base*>(m_protocol.get()), m_screen, name}
   {
     this->m_capabilities.change_tree = true;
+    m_screen->setTitle(QString::fromStdString(name));
 
     {
       auto screen_node
           = std::make_unique<ossia::net::generic_node>("screen", *this, m_root);
-      auto screen_param = screen_node->create_parameter(ossia::val_type::INT);
+      auto screen_param = screen_node->create_parameter(ossia::val_type::STRING);
       screen_param->set_domain(ossia::make_domain(int(0), int(100)));
       screen_param->add_callback([this](const ossia::value& v) {
         if(auto val = v.target<int>())
@@ -96,6 +81,20 @@ public:
             }
           });
         }
+        else if(auto val = v.target<std::string>())
+        {
+          ossia::qt::run_async(&m_qtContext, [screen = this->m_screen, scr = *val] {
+            const auto& cur_screens = qApp->screens();
+            for(auto s : cur_screens)
+            {
+              if(s->name() == scr.c_str())
+              {
+                screen->setScreen(s);
+                break;
+              }
+            }
+          });
+        }
       });
       m_root.add_child(std::move(screen_node));
     }
@@ -112,6 +111,15 @@ public:
           });
         }
       });
+
+      m_screen->onWindowMove = [this, pos_param](QPointF pos) {
+        if(const auto& w = m_screen->window())
+        {
+          auto geom = w->geometry();
+          pos_param->set_value(
+              ossia::vec2f{float(pos.x()), float(pos.y())});
+        }
+      };
       m_root.add_child(std::move(pos_node));
     }
 
@@ -137,6 +145,20 @@ public:
         abs_win->push_value(ossia::vec2f{0.f, 0.f});
         node->add_child(std::move(abs_node));
       }
+      {
+        auto visible
+            = std::make_unique<ossia::net::generic_node>("visible", *this, *node);
+        auto param = visible->create_parameter(ossia::val_type::BOOL);
+        param->add_callback([this](const ossia::value& v) {
+          if(auto val = v.target<bool>())
+          {
+            ossia::qt::run_async(&m_qtContext, [screen = this->m_screen, v = *val] {
+              screen->setCursor(v);
+            });
+          }
+        });
+        node->add_child(std::move(visible));
+      }
 
       m_screen->onMouseMove = [this, scaled_win, abs_win](QPointF screen, QPointF win) {
         if(const auto& w = m_screen->window())
@@ -378,6 +400,12 @@ void WindowDevice::setupContextMenu(QMenu& menu) const
   }
 }
 
+void WindowDevice::disconnect()
+{
+  DeviceInterface::disconnect();
+  m_dev = {};
+}
+
 bool WindowDevice::reconnect()
 {
   disconnect();
