@@ -7,6 +7,9 @@
 #include <Gfx/Filter/Layer.hpp>
 #include <Gfx/Filter/Library.hpp>
 #include <Gfx/Filter/Process.hpp>
+#include <Gfx/GeometryFilter/Executor.hpp>
+#include <Gfx/GeometryFilter/Layer.hpp>
+#include <Gfx/GeometryFilter/Process.hpp>
 #include <Gfx/GfxApplicationPlugin.hpp>
 #include <Gfx/GfxDevice.hpp>
 #include <Gfx/Images/Executor.hpp>
@@ -27,6 +30,10 @@
 
 #include <score/plugins/FactorySetup.hpp>
 
+#if defined(SCORE_HAS_SH4LT)
+#include <Gfx/Sh4lt/Sh4ltInputDevice.hpp>
+#include <Gfx/Sh4lt/Sh4ltOutputDevice.hpp>
+#endif
 #if defined(SCORE_HAS_SHMDATA)
 #include <Gfx/Shmdata/ShmdataInputDevice.hpp>
 #include <Gfx/Shmdata/ShmdataOutputDevice.hpp>
@@ -72,6 +79,10 @@ std::vector<score::InterfaceBase*> score_plugin_gfx::factories(
          ,
          Gfx::LibavOutputProtocolFactory
 #endif
+#if defined(SCORE_HAS_SH4LT)
+         ,
+         Gfx::Sh4lt::InputFactory, Gfx::Sh4ltOutputProtocolFactory
+#endif
 #if defined(SCORE_HAS_SHMDATA)
          ,
          Gfx::Shmdata::InputFactory, Gfx::ShmdataOutputProtocolFactory
@@ -90,11 +101,13 @@ std::vector<score::InterfaceBase*> score_plugin_gfx::factories(
 #endif
          >,
       FW<Process::ProcessModelFactory, Gfx::Filter::ProcessFactory,
-         Gfx::Video::ProcessFactory, Gfx::Text::ProcessFactory,
-         Gfx::Images::ProcessFactory>,
-      FW<Process::LayerFactory, Gfx::Filter::LayerFactory, Gfx::Video::LayerFactory>,
+         Gfx::GeometryFilter::ProcessFactory, Gfx::Video::ProcessFactory,
+         Gfx::Text::ProcessFactory, Gfx::Images::ProcessFactory>,
+      FW<Process::LayerFactory, Gfx::Filter::LayerFactory,
+         Gfx::GeometryFilter::LayerFactory, Gfx::Video::LayerFactory>,
       FW<Execution::ProcessComponentFactory,
          Gfx::Filter::ProcessExecutorComponentFactory,
+         Gfx::GeometryFilter::ProcessExecutorComponentFactory,
          Gfx::Video::ProcessExecutorComponentFactory,
          Gfx::Text::ProcessExecutorComponentFactory,
          Gfx::Images::ProcessExecutorComponentFactory>,
