@@ -14,6 +14,7 @@
 #include <JS/LibraryHandler.hpp>
 #include <JS/Qml/AddressItem.hpp>
 #include <JS/Qml/DeviceEnumerator.hpp>
+#include <JS/Qml/PortSink.hpp>
 #include <JS/Qml/PortSource.hpp>
 #include <JS/Qml/QmlObjects.hpp>
 #include <JS/Qml/Utils.hpp>
@@ -69,15 +70,17 @@ score_plugin_js::score_plugin_js()
   qmlRegisterType<JS::VideoFileChooser>("Score", 1, 0, "VideoFileChooser");
 
   qmlRegisterType<JS::Enum>("Score", 1, 0, "Enum");
+  qmlRegisterType<JS::ComboBox>("Score", 1, 0, "ComboBox");
   qmlRegisterType<JS::Toggle>("Score", 1, 0, "Toggle");
   qmlRegisterType<JS::Impulse>("Score", 1, 0, "Impulse");
   qmlRegisterType<JS::Button>("Score", 1, 0, "Button");
   qmlRegisterType<JS::LineEdit>("Score", 1, 0, "LineEdit");
   qmlRegisterType<JS::Script>("Score", 1, 0, "Script");
 
-  qmlRegisterType<JS::AddressSource>("Score", 1, 0, "AddressSource");
-  qmlRegisterType<JS::PortSource>("Score", 1, 0, "PortSource");
-  qmlRegisterType<JS::GlobalDeviceEnumerator>("Score", 1, 0, "DeviceEnumerator");
+  qmlRegisterType<JS::AddressSource>("Score.UI", 1, 0, "AddressSource");
+  qmlRegisterType<JS::PortSource>("Score.UI", 1, 0, "PortSource");
+  qmlRegisterType<JS::PortSink>("Score.UI", 1, 0, "PortSink");
+  qmlRegisterType<JS::GlobalDeviceEnumerator>("Score.UI", 1, 0, "DeviceEnumerator");
 
   qRegisterMetaType<QVector<JS::MidiMessage>>();
 
