@@ -53,8 +53,9 @@ public:
   ossia::vec3f position, center;
   float fov{90.f}, near{0.001f}, far{10000.f};
 
-  int wantedProjection{};
+  int texture_projection{};
   int draw_mode{};
+  int camera_mode{};
 };
 
 }
