@@ -259,6 +259,7 @@ void ApplicationPlugin::rescanVSTs(QStringList paths)
 #endif
 }
 
+static int vst_in_flight = 0;
 void ApplicationPlugin::processIncomingMessage(const QString& txt)
 {
 #if QT_CONFIG(process)
@@ -276,6 +277,7 @@ void ApplicationPlugin::processIncomingMessage(const QString& txt)
         m_processes[id].process->close();
         if(m_processes[id].process->state() == QProcess::ProcessState::NotRunning)
         {
+          vst_in_flight--;
           m_processes[id] = {};
         }
         else
@@ -283,13 +285,16 @@ void ApplicationPlugin::processIncomingMessage(const QString& txt)
           connect(
               m_processes[id].process.get(),
               qOverload<int, QProcess::ExitStatus>(&QProcess::finished), this,
-              [this, id] { m_processes[id] = {}; });
+              [this, id] {
+            vst_in_flight--;
+            m_processes[id] = {};
+          });
         }
       }
     }
     else
     {
-      qDebug() << "Got invalid VST3 request ID" << id;
+      qDebug() << "Got invalid VST request ID" << id;
     }
   }
 #endif
@@ -299,7 +304,6 @@ void ApplicationPlugin::scanVSTsEvent()
 {
 #if QT_CONFIG(process)
   constexpr int max_in_flight = 8;
-  int in_flight = 0;
 
   for(auto& proc : m_processes)
   {
@@ -309,25 +313,29 @@ void ApplicationPlugin::scanVSTsEvent()
 
     if(!proc.scanning)
     {
-      proc.process->start(QProcess::ReadOnly);
-      proc.scanning = true;
-      proc.timer.start();
+      if(vst_in_flight < max_in_flight)
+      {
+        proc.process->start(QProcess::ReadOnly);
+        proc.scanning = true;
+        proc.timer.start();
 
-      in_flight++;
+        vst_in_flight++;
+      }
     }
     else
     {
       if(proc.timer.elapsed() > 10000)
       {
         addInvalidVST(proc.path);
+        proc.process->kill();
         proc.process.reset();
 
-        in_flight--;
+        vst_in_flight--;
         continue;
       }
     }
 
-    if(in_flight == max_in_flight)
+    if(vst_in_flight == max_in_flight)
     {
       QTimer::singleShot(1000, this, &ApplicationPlugin::scanVSTsEvent);
       return;
